typedef struct _pnp_vendor {
	const uTCHAR id[4];
	const uTCHAR name[80];
} _pnp_vendor;

static const _pnp_vendor vendors[] = {
	{uL("AAA"), uL("Avolites Ltd")},
	{uL("AAE"), uL("Anatek Electronics Inc.")},
	{uL("AAM"), uL("Aava Mobile Oy")},
	{uL("AAN"), uL("AAEON Technology Inc.")},
	{uL("AAT"), uL("Ann Arbor Technologies")},
	{uL("ABA"), uL("ABBAHOME INC.")},
	{uL("ABC"), uL("AboCom System Inc.")},
	{uL("ABD"), uL("Allen Bradley Company")},
	{uL("ABE"), uL("Alcatel Bell")},
	{uL("ABO"), uL("D-Link Systems Inc")},
	{uL("ABS"), uL("Abaco Systems, Inc.")},
	{uL("ABT"), uL("Anchor Bay Technologies, Inc.")},
	{uL("ABV"), uL("Advanced Research Technology")},
	{uL("ACA"), uL("Ariel Corporation")},
	{uL("ACB"), uL("Aculab Ltd")},
	{uL("ACC"), uL("Accton Technology Corporation")},
	{uL("ACD"), uL("AWETA BV")},
	{uL("ACE"), uL("Actek Engineering Pty Ltd")},
	{uL("ACG"), uL("A&R Cambridge Ltd.")},
	{uL("ACH"), uL("Archtek Telecom Corporation")},
	{uL("ACI"), uL("Ancor Communications Inc")},
	{uL("ACK"), uL("Acksys")},
	{uL("ACL"), uL("Apricot Computers")},
	{uL("ACM"), uL("Acroloop Motion Control Systems Inc")},
	{uL("ACO"), uL("Allion Computer Inc.")},
	{uL("ACP"), uL("Aspen Tech Inc")},
	{uL("ACR"), uL("Acer Technologies")},
	{uL("ACS"), uL("Altos Computer Systems")},
	{uL("ACT"), uL("Applied Creative Technology")},
	{uL("ACU"), uL("Acculogic")},
	{uL("ACV"), uL("ActivCard S.A")},
	{uL("ADA"), uL("Addi-Data GmbH")},
	{uL("ADB"), uL("Aldebbaron")},
	{uL("ADC"), uL("Acnhor Datacomm")},
	{uL("ADD"), uL("Advanced Peripheral Devices Inc")},
	{uL("ADE"), uL("Arithmos, Inc.")},
	{uL("ADH"), uL("Aerodata Holdings Ltd")},
	{uL("ADI"), uL("ADI Systems Inc")},
	{uL("ADK"), uL("Adtek System Science Company Ltd")},
	{uL("ADL"), uL("ASTRA Security Products Ltd")},
	{uL("ADM"), uL("Ad Lib MultiMedia Inc")},
	{uL("ADN"), uL("Analog & Digital Devices Tel. Inc")},
	{uL("ADP"), uL("Adaptec Inc")},
	{uL("ADR"), uL("Nasa Ames Research Center")},
	{uL("ADS"), uL("Analog Devices Inc")},
	{uL("ADT"), uL("Adtek")},
	{uL("ADV"), uL("Advanced Micro Devices Inc")},
	{uL("ADX"), uL("Adax Inc")},
	{uL("ADZ"), uL("ADDER TECHNOLOGY LTD")},
	{uL("AEC"), uL("Antex Electronics Corporation")},
	{uL("AED"), uL("Advanced Electronic Designs, Inc.")},
	{uL("AEI"), uL("Actiontec Electric Inc")},
	{uL("AEJ"), uL("Alpha Electronics Company")},
	{uL("AEM"), uL("ASEM S.p.A.")},
	{uL("AEN"), uL("Avencall")},
	{uL("AEP"), uL("Aetas Peripheral International")},
	{uL("AET"), uL("Aethra Telecomunicazioni S.r.l.")},
	{uL("AFA"), uL("Alfa Inc")},
	{uL("AGC"), uL("Beijing Aerospace Golden Card Electronic Engineering Co.,Ltd.")},
	{uL("AGI"), uL("Artish Graphics Inc")},
	{uL("AGL"), uL("Argolis")},
	{uL("AGM"), uL("Advan Int'l Corporation")},
	{uL("AGO"), uL("AlgolTek, Inc.")},
	{uL("AGT"), uL("Agilent Technologies")},
	{uL("AHC"), uL("Advantech Co., Ltd.")},
	{uL("AHQ"), uL("Astro HQ LLC")},
	{uL("AHS"), uL("Beijing AnHeng SecoTech Information Technology Co., Ltd.")},
	{uL("AIC"), uL("Arnos Insturments & Computer Systems")},
	{uL("AIE"), uL("Altmann Industrieelektronik")},
	{uL("AII"), uL("Amptron International Inc.")},
	{uL("AIK"), uL("Dongguan Alllike Electronics Co., Ltd.")},
	{uL("AIL"), uL("Altos India Ltd")},
	{uL("AIM"), uL("AIMS Lab Inc")},
	{uL("AIR"), uL("Advanced Integ. Research Inc")},
	{uL("AIS"), uL("Alien Internet Services")},
	{uL("AIW"), uL("Aiwa Company Ltd")},
	{uL("AIX"), uL("ALTINEX, INC.")},
	{uL("AJA"), uL("AJA Video Systems, Inc.")},
	{uL("AKB"), uL("Akebia Ltd")},
	{uL("AKE"), uL("AKAMI Electric Co.,Ltd")},
	{uL("AKI"), uL("AKIA Corporation")},
	{uL("AKL"), uL("AMiT Ltd")},
	{uL("AKM"), uL("Asahi Kasei Microsystems Company Ltd")},
	{uL("AKP"), uL("Atom Komplex Prylad")},
	{uL("AKR"), uL("Anker Innovations Limited")},
	{uL("AKY"), uL("Askey Computer Corporation")},
	{uL("ALA"), uL("Alacron Inc")},
	{uL("ALC"), uL("Altec Corporation")},
	{uL("ALD"), uL("In4S Inc")},
	{uL("ALE"), uL("Alenco BV")},
	{uL("ALG"), uL("Realtek Semiconductor Corp.")},
	{uL("ALH"), uL("AL Systems")},
	{uL("ALI"), uL("Acer Labs")},
	{uL("ALJ"), uL("Altec Lansing")},
	{uL("ALK"), uL("Acrolink Inc")},
	{uL("ALL"), uL("Alliance Semiconductor Corporation")},
	{uL("ALM"), uL("Acutec Ltd.")},
	{uL("ALN"), uL("Alana Technologies")},
	{uL("ALO"), uL("Algolith Inc.")},
	{uL("ALP"), uL("ALPS ALPINE CO., LTD.")},
	{uL("ALR"), uL("Advanced Logic")},
	{uL("ALS"), uL("Avance Logic Inc")},
	{uL("ALT"), uL("Altra")},
	{uL("ALV"), uL("AlphaView LCD")},
	{uL("ALX"), uL("ALEXON Co.,Ltd.")},
	{uL("AMA"), uL("Asia Microelectronic Development Inc")},
	{uL("AMB"), uL("Ambient Technologies, Inc.")},
	{uL("AMC"), uL("Attachmate Corporation")},
	{uL("AMD"), uL("Amdek Corporation")},
	{uL("AMI"), uL("American Megatrends Inc")},
	{uL("AML"), uL("Anderson Multimedia Communications (HK) Limited")},
	{uL("AMN"), uL("Amimon LTD.")},
	{uL("AMO"), uL("Amino Technologies PLC and Amino Communications Limited")},
	{uL("AMP"), uL("AMP Inc")},
	{uL("AMR"), uL("AmTRAN Technology Co., Ltd.")},
	{uL("AMS"), uL("ARMSTEL, Inc.")},
	{uL("AMT"), uL("AMT International Industry")},
	{uL("AMX"), uL("AMX LLC")},
	{uL("ANA"), uL("Anakron")},
	{uL("ANC"), uL("Ancot")},
	{uL("AND"), uL("Adtran Inc")},
	{uL("ANI"), uL("Anigma Inc")},
	{uL("ANK"), uL("Anko Electronic Company Ltd")},
	{uL("ANL"), uL("Analogix Semiconductor, Inc")},
	{uL("ANO"), uL("Anorad Corporation")},
	{uL("ANP"), uL("Andrew Network Production")},
	{uL("ANR"), uL("ANR Ltd")},
	{uL("ANS"), uL("Ansel Communication Company")},
	{uL("ANT"), uL("Ace CAD Enterprise Company Ltd")},
	{uL("ANV"), uL("Beijing ANTVR Technology Co., Ltd.")},
	{uL("ANW"), uL("Analog Way SAS")},
	{uL("ANX"), uL("Acer Netxus Inc")},
	{uL("AOA"), uL("AOpen Inc.")},
	{uL("AOE"), uL("Advanced Optics Electronics, Inc.")},
	{uL("AOL"), uL("America OnLine")},
	{uL("AOT"), uL("Alcatel")},
	{uL("APC"), uL("American Power Conversion")},
	{uL("APD"), uL("AppliAdata")},
	{uL("APE"), uL("ALPS ALPINE CO., LTD.")},
	{uL("APG"), uL("Horner Electric Inc")},
	{uL("API"), uL("A Plus Info Corporation")},
	{uL("APL"), uL("Aplicom Oy")},
	{uL("APM"), uL("Applied Memory Tech")},
	{uL("APN"), uL("Appian Tech Inc")},
	{uL("APP"), uL("Apple Computer Inc")},
	{uL("APR"), uL("Aprilia s.p.a.")},
	{uL("APS"), uL("Autologic Inc")},
	{uL("APT"), uL("Audio Processing Technology Ltd")},
	{uL("APV"), uL("A+V Link")},
	{uL("APX"), uL("AP Designs Ltd")},
	{uL("ARC"), uL("Alta Research Corporation")},
	{uL("ARD"), uL("AREC Inc.")},
	{uL("ARE"), uL("ICET S.p.A.")},
	{uL("ARG"), uL("Argus Electronics Co., LTD")},
	{uL("ARI"), uL("Argosy Research Inc")},
	{uL("ARK"), uL("Ark Logic Inc")},
	{uL("ARL"), uL("Arlotto Comnet Inc")},
	{uL("ARM"), uL("Arima")},
	{uL("ARO"), uL("Poso International B.V.")},
	{uL("ARR"), uL("ARRIS Group, Inc.")},
	{uL("ARS"), uL("Arescom Inc")},
	{uL("ART"), uL("Corion Industrial Corporation")},
	{uL("ASC"), uL("Ascom Strategic Technology Unit")},
	{uL("ASD"), uL("USC Information Sciences Institute")},
	{uL("ASE"), uL("AseV Display Labs")},
	{uL("ASH"), uL("Ashton Bentley Concepts")},
	{uL("ASI"), uL("Ahead Systems")},
	{uL("ASK"), uL("Ask A/S")},
	{uL("ASL"), uL("AccuScene Corporation Ltd")},
	{uL("ASM"), uL("ASEM S.p.A.")},
	{uL("ASN"), uL("Asante Tech Inc")},
	{uL("ASP"), uL("ASP Microelectronics Ltd")},
	{uL("AST"), uL("AST Research Inc")},
	{uL("ASU"), uL("Asuscom Network Inc")},
	{uL("ASX"), uL("AudioScience")},
	{uL("ASY"), uL("Rockwell Collins / Airshow Systems")},
	{uL("ATA"), uL("Allied Telesyn International (Asia) Pte Ltd")},
	{uL("ATC"), uL("Ably-Tech Corporation")},
	{uL("ATD"), uL("Alpha Telecom Inc")},
	{uL("ATE"), uL("Innovate Ltd")},
	{uL("ATH"), uL("Athena Informatica S.R.L.")},
	{uL("ATI"), uL("Allied Telesis KK")},
	{uL("ATJ"), uL("ArchiTek Corporation")},
	{uL("ATK"), uL("Allied Telesyn Int'l")},
	{uL("ATL"), uL("Arcus Technology Ltd")},
	{uL("ATM"), uL("ATM Ltd")},
	{uL("ATN"), uL("Athena Smartcard Solutions Ltd.")},
	{uL("ATO"), uL("ASTRO DESIGN, INC.")},
	{uL("ATP"), uL("Alpha-Top Corporation")},
	{uL("ATT"), uL("AT&T")},
	{uL("ATV"), uL("Office Depot, Inc.")},
	{uL("ATX"), uL("Athenix Corporation")},
	{uL("AUD"), uL("AudioControl")},
	{uL("AUG"), uL("August Home, Inc.")},
	{uL("AUI"), uL("ALPS ALPINE CO., LTD.")},
	{uL("AUO"), uL("DO NOT USE - AUO")},
	{uL("AUR"), uL("Aureal Semiconductor")},
	{uL("AUS"), uL("ASUSTek COMPUTER INC")},
	{uL("AUT"), uL("Autotime Corporation")},
	{uL("AUV"), uL("Auvidea GmbH")},
	{uL("AVA"), uL("Avaya Communication")},
	{uL("AVC"), uL("Auravision Corporation")},
	{uL("AVD"), uL("Avid Electronics Corporation")},
	{uL("AVE"), uL("Add Value Enterpises (Asia) Pte Ltd")},
	{uL("AVG"), uL("Avegant Corporation")},
	{uL("AVI"), uL("Nippon Avionics Co.,Ltd")},
	{uL("AVJ"), uL("Atelier Vision Corporation")},
	{uL("AVL"), uL("Avalue Technology Inc.")},
	{uL("AVM"), uL("AVM GmbH")},
	{uL("AVN"), uL("Advance Computer Corporation")},
	{uL("AVO"), uL("Avocent Corporation")},
	{uL("AVR"), uL("AVer Information Inc.")},
	{uL("AVS"), uL("Avatron Software Inc.")},
	{uL("AVT"), uL("Avtek (Electronics) Pty Ltd")},
	{uL("AVV"), uL("SBS Technologies (Canada), Inc. (was Avvida Systems, Inc.)")},
	{uL("AVX"), uL("A/Vaux Electronics")},
	{uL("AWC"), uL("Access Works Comm Inc")},
	{uL("AWL"), uL("Aironet Wireless Communications, Inc")},
	{uL("AWS"), uL("Wave Systems")},
	{uL("AXB"), uL("Adrienne Electronics Corporation")},
	{uL("AXC"), uL("AXIOMTEK CO., LTD.")},
	{uL("AXE"), uL("Axell Corporation")},
	{uL("AXI"), uL("American Magnetics")},
	{uL("AXL"), uL("Axel")},
	{uL("AXO"), uL("Axonic Labs LLC")},
	{uL("AXP"), uL("American Express")},
	{uL("AXT"), uL("Axtend Technologies Inc")},
	{uL("AXX"), uL("Axxon Computer Corporation")},
	{uL("AXY"), uL("AXYZ Automation Services, Inc")},
	{uL("AYD"), uL("Aydin Displays")},
	{uL("AYR"), uL("Airlib, Inc")},
	{uL("AZH"), uL("Shenzhen three Connaught Information Technology Co., Ltd. (3nod Group)")},
	{uL("AZM"), uL("AZ Middelheim - Radiotherapy")},
	{uL("AZT"), uL("Aztech Systems Ltd")},
	{uL("BAC"), uL("Biometric Access Corporation")},
	{uL("BAN"), uL("Banyan")},
	{uL("BBB"), uL("an-najah university")},
	{uL("BBH"), uL("B&Bh")},
	{uL("BBL"), uL("Brain Boxes Limited")},
	{uL("BBV"), uL("BlueBox Video Limited")},
	{uL("BBX"), uL("Black Box Corporation")},
	{uL("BCC"), uL("Beaver Computer Corporaton")},
	{uL("BCD"), uL("Barco GmbH")},
	{uL("BCI"), uL("Broadata Communications Inc.")},
	{uL("BCM"), uL("Broadcom")},
	{uL("BCQ"), uL("Deutsche Telekom Berkom GmbH")},
	{uL("BCS"), uL("Booria CAD/CAM systems")},
	{uL("BDO"), uL("Brahler ICS")},
	{uL("BDR"), uL("Blonder Tongue Labs, Inc.")},
	{uL("BDS"), uL("Barco Display Systems")},
	{uL("BEC"), uL("Beckhoff Automation")},
	{uL("BEI"), uL("Beckworth Enterprises Inc")},
	{uL("BEK"), uL("Beko Elektronik A.S.")},
	{uL("BEL"), uL("Beltronic Industrieelektronik GmbH")},
	{uL("BEO"), uL("Baug & Olufsen")},
	{uL("BFE"), uL("B.F. Engineering Corporation")},
	{uL("BGB"), uL("Barco Graphics N.V")},
	{uL("BGT"), uL("Budzetron Inc")},
	{uL("BHZ"), uL("BitHeadz, Inc.")},
	{uL("BIA"), uL("Biamp Systems Corporation")},
	{uL("BIC"), uL("Big Island Communications")},
	{uL("BII"), uL("Boeckeler Instruments Inc")},
	{uL("BIL"), uL("Billion Electric Company Ltd")},
	{uL("BIO"), uL("BioLink Technologies International, Inc.")},
	{uL("BIT"), uL("Bit 3 Computer")},
	{uL("BLD"), uL("BILD INNOVATIVE TECHNOLOGY LLC")},
	{uL("BLI"), uL("Busicom")},
	{uL("BLN"), uL("BioLink Technologies")},
	{uL("BLP"), uL("Bloomberg L.P.")},
	{uL("BMD"), uL("Blackmagic Design")},
	{uL("BMI"), uL("Benson Medical Instruments Company")},
	{uL("BML"), uL("BIOMED Lab")},
	{uL("BMS"), uL("BIOMEDISYS")},
	{uL("BNE"), uL("Bull AB")},
	{uL("BNK"), uL("Banksia Tech Pty Ltd")},
	{uL("BNO"), uL("Bang & Olufsen")},
	{uL("BNS"), uL("Boulder Nonlinear Systems")},
	{uL("BOB"), uL("Rainy Orchard")},
	{uL("BOE"), uL("BOE")},
	{uL("BOI"), uL("NINGBO BOIGLE DIGITAL TECHNOLOGY CO.,LTD")},
	{uL("BOS"), uL("BOS")},
	{uL("BPD"), uL("Micro Solutions, Inc.")},
	{uL("BPS"), uL("Barco, N.V.")},
	{uL("BPU"), uL("Best Power")},
	{uL("BRA"), uL("Braemac Pty Ltd")},
	{uL("BRC"), uL("BARC")},
	{uL("BRG"), uL("Bridge Information Co., Ltd")},
	{uL("BRI"), uL("Boca Research Inc")},
	{uL("BRM"), uL("Braemar Inc")},
	{uL("BRO"), uL("BROTHER INDUSTRIES,LTD.")},
	{uL("BSE"), uL("Bose Corporation")},
	{uL("BSG"), uL("Robert Bosch GmbH")},
	{uL("BSL"), uL("Biomedical Systems Laboratory")},
	{uL("BSN"), uL("BRIGHTSIGN, LLC")},
	{uL("BST"), uL("BodySound Technologies, Inc.")},
	{uL("BTC"), uL("Bit 3 Computer")},
	{uL("BTE"), uL("Brilliant Technology")},
	{uL("BTF"), uL("Bitfield Oy")},
	{uL("BTI"), uL("BusTech Inc")},
	{uL("BTO"), uL("BioTao Ltd")},
	{uL("BUF"), uL("Yasuhiko Shirai Melco Inc")},
	{uL("BUG"), uL("B.U.G., Inc.")},
	{uL("BUJ"), uL("ATI Tech Inc")},
	{uL("BUL"), uL("Bull")},
	{uL("BUR"), uL("B&R Industrial Automation GmbH")},
	{uL("BUS"), uL("BusTek")},
	{uL("BUT"), uL("21ST CENTURY ENTERTAINMENT")},
	{uL("BWK"), uL("Bitworks Inc.")},
	{uL("BXE"), uL("Buxco Electronics")},
	{uL("BYD"), uL("byd:sign corporation")},
	{uL("CAA"), uL("Castles Automation Co., Ltd")},
	{uL("CAC"), uL("CA & F Elettronica")},
	{uL("CAG"), uL("CalComp")},
	{uL("CAI"), uL("Canon Inc.")},
	{uL("CAL"), uL("Acon")},
	{uL("CAM"), uL("Cambridge Audio")},
	{uL("CAN"), uL("Canopus Company Ltd")},
	{uL("CAR"), uL("Cardinal Company Ltd")},
	{uL("CAS"), uL("CASIO COMPUTER CO.,LTD")},
	{uL("CAT"), uL("Consultancy in Advanced Technology")},
	{uL("CAV"), uL("Cavium Networks, Inc")},
	{uL("CBI"), uL("ComputerBoards Inc")},
	{uL("CBR"), uL("Cebra Tech A/S")},
	{uL("CBT"), uL("Cabletime Ltd")},
	{uL("CBX"), uL("Cybex Computer Products Corporation")},
	{uL("CCC"), uL("C-Cube Microsystems")},
	{uL("CCI"), uL("Cache")},
	{uL("CCJ"), uL("CONTEC CO.,LTD.")},
	{uL("CCL"), uL("CCL/ITRI")},
	{uL("CCP"), uL("Capetronic USA Inc")},
	{uL("CDC"), uL("Core Dynamics Corporation")},
	{uL("CDD"), uL("Convergent Data Devices")},
	{uL("CDE"), uL("Colin.de")},
	{uL("CDG"), uL("Christie Digital Systems Inc")},
	{uL("CDI"), uL("Concept Development Inc")},
	{uL("CDK"), uL("Cray Communications")},
	{uL("CDN"), uL("Codenoll Technical Corporation")},
	{uL("CDP"), uL("CalComp")},
	{uL("CDS"), uL("Computer Diagnostic Systems")},
	{uL("CDT"), uL("IBM Corporation")},
	{uL("CDV"), uL("Convergent Design Inc.")},
	{uL("CEA"), uL("Consumer Electronics Association")},
	{uL("CEC"), uL("Chicony Electronics Company Ltd")},
	{uL("CED"), uL("Cambridge Electronic Design Ltd")},
	{uL("CEF"), uL("Cefar Digital Vision")},
	{uL("CEI"), uL("Crestron Electronics, Inc.")},
	{uL("CEM"), uL("MEC Electronics GmbH")},
	{uL("CEN"), uL("Centurion Technologies P/L")},
	{uL("CEP"), uL("C-DAC")},
	{uL("CER"), uL("Ceronix")},
	{uL("CET"), uL("TEC CORPORATION")},
	{uL("CFG"), uL("Atlantis")},
	{uL("CFR"), uL("Meta View, Inc.")},
	{uL("CGA"), uL("Chunghwa Picture Tubes, LTD")},
	{uL("CGS"), uL("Chyron Corp")},
	{uL("CGT"), uL("congatec AG")},
	{uL("CHA"), uL("Chase Research PLC")},
	{uL("CHD"), uL("ChangHong Electric Co.,Ltd")},
	{uL("CHE"), uL("Acer Inc")},
	{uL("CHG"), uL("Sichuan Changhong Electric CO, LTD.")},
	{uL("CHI"), uL("Chrontel Inc")},
	{uL("CHL"), uL("Chloride-R&D")},
	{uL("CHM"), uL("CHIC TECHNOLOGY CORP.")},
	{uL("CHO"), uL("Sichuang Changhong Corporation")},
	{uL("CHP"), uL("CH Products")},
	{uL("CHR"), uL("christmann informationstechnik + medien GmbH & Co. KG")},
	{uL("CHS"), uL("Agentur Chairos")},
	{uL("CHT"), uL("Chunghwa Picture Tubes,LTD.")},
	{uL("CHY"), uL("Cherry GmbH")},
	{uL("CIC"), uL("Comm. Intelligence Corporation")},
	{uL("CIE"), uL("Convergent Engineering, Inc.")},
	{uL("CII"), uL("Cromack Industries Inc")},
	{uL("CIL"), uL("Citicom Infotech Private Limited")},
	{uL("CIN"), uL("Citron GmbH")},
	{uL("CIP"), uL("Ciprico Inc")},
	{uL("CIR"), uL("Cirrus Logic Inc")},
	{uL("CIS"), uL("Cisco Systems Inc")},
	{uL("CIT"), uL("Citifax Limited")},
	{uL("CKC"), uL("The Concept Keyboard Company Ltd")},
	{uL("CKJ"), uL("Carina System Co., Ltd.")},
	{uL("CLA"), uL("Clarion Company Ltd")},
	{uL("CLD"), uL("COMMAT L.t.d.")},
	{uL("CLE"), uL("Classe Audio")},
	{uL("CLG"), uL("CoreLogic")},
	{uL("CLI"), uL("Cirrus Logic Inc")},
	{uL("CLM"), uL("CrystaLake Multimedia")},
	{uL("CLO"), uL("Clone Computers")},
	{uL("CLR"), uL("Clover Electronics")},
	{uL("CLT"), uL("automated computer control systems")},
	{uL("CLV"), uL("Clevo Company")},
	{uL("CLX"), uL("CardLogix")},
	{uL("CMC"), uL("CMC Ltd")},
	{uL("CMD"), uL("Colorado MicroDisplay, Inc.")},
	{uL("CMG"), uL("Chenming Mold Ind. Corp.")},
	{uL("CMI"), uL("C-Media Electronics")},
	{uL("CMK"), uL("Comark LLC")},
	{uL("CMM"), uL("Comtime GmbH")},
	{uL("CMN"), uL("Chimei Innolux Corporation")},
	{uL("CMO"), uL("Chi Mei Optoelectronics corp.")},
	{uL("CMR"), uL("Cambridge Research Systems Ltd")},
	{uL("CMS"), uL("CompuMaster Srl")},
	{uL("CMX"), uL("Comex Electronics AB")},
	{uL("CNB"), uL("American Power Conversion")},
	{uL("CNC"), uL("Alvedon Computers Ltd")},
	{uL("CND"), uL("Micro-Star Int'l Co., Ltd.")},
	{uL("CNE"), uL("Cine-tal")},
	{uL("CNI"), uL("Connect Int'l A/S")},
	{uL("CNN"), uL("Canon Inc")},
	{uL("CNT"), uL("COINT Multimedia Systems")},
	{uL("COB"), uL("COBY Electronics Co., Ltd")},
	{uL("COD"), uL("CODAN Pty. Ltd.")},
	{uL("COI"), uL("Codec Inc.")},
	{uL("COL"), uL("Rockwell Collins, Inc.")},
	{uL("COM"), uL("Comtrol Corporation")},
	{uL("CON"), uL("Contec Company Ltd")},
	{uL("COO"), uL("coolux GmbH")},
	{uL("COR"), uL("Corollary Inc")},
	{uL("COS"), uL("CoStar Corporation")},
	{uL("COT"), uL("Core Technology Inc")},
	{uL("COW"), uL("Polycow Productions")},
	{uL("COX"), uL("Comrex")},
	{uL("CPC"), uL("Ciprico Inc")},
	{uL("CPD"), uL("CompuAdd")},
	{uL("CPI"), uL("Computer Peripherals Inc")},
	{uL("CPL"), uL("Compal Electronics Inc")},
	{uL("CPM"), uL("Capella Microsystems Inc.")},
	{uL("CPP"), uL("Compound Photonics")},
	{uL("CPQ"), uL("Compaq Computer Company")},
	{uL("CPT"), uL("cPATH")},
	{uL("CPX"), uL("Powermatic Data Systems")},
	{uL("CRA"), uL("CRALTECH ELECTRONICA, S.L.")},
	{uL("CRC"), uL("CONRAC GmbH")},
	{uL("CRD"), uL("Cardinal Technical Inc")},
	{uL("CRE"), uL("Creative Labs Inc")},
	{uL("CRH"), uL("Contemporary Research Corp.")},
	{uL("CRI"), uL("Crio Inc.")},
	{uL("CRL"), uL("Creative Logic  ")},
	{uL("CRM"), uL("CORSAIR MEMORY Inc.")},
	{uL("CRN"), uL("Cornerstone Imaging")},
	{uL("CRO"), uL("Extraordinary Technologies PTY Limited")},
	{uL("CRQ"), uL("Cirque Corporation")},
	{uL("CRS"), uL("Crescendo Communication Inc")},
	{uL("CRV"), uL("Cerevo Inc.")},
	{uL("CRW"), uL("Cammegh Limited")},
	{uL("CRX"), uL("Cyrix Corporation")},
	{uL("CSB"), uL("Transtex SA")},
	{uL("CSC"), uL("Crystal Semiconductor")},
	{uL("CSD"), uL("Cresta Systems Inc")},
	{uL("CSE"), uL("Concept Solutions & Engineering")},
	{uL("CSI"), uL("Cabletron System Inc")},
	{uL("CSL"), uL("Cloudium Systems Ltd.")},
	{uL("CSM"), uL("Cosmic Engineering Inc.")},
	{uL("CSO"), uL("California Institute of Technology")},
	{uL("CSS"), uL("CSS Laboratories")},
	{uL("CST"), uL("CSTI Inc")},
	{uL("CTA"), uL("CoSystems Inc")},
	{uL("CTC"), uL("CTC Communication Development Company Ltd")},
	{uL("CTE"), uL("Chunghwa Telecom Co., Ltd.")},
	{uL("CTL"), uL("Creative Technology Ltd")},
	{uL("CTM"), uL("Computerm Corporation")},
	{uL("CTN"), uL("Computone Products")},
	{uL("CTP"), uL("Computer Technology Corporation")},
	{uL("CTR"), uL("Control4 Corporation")},
	{uL("CTS"), uL("Comtec Systems Co., Ltd.")},
	{uL("CTX"), uL("Creatix Polymedia GmbH")},
	{uL("CUB"), uL("Cubix Corporation")},
	{uL("CUK"), uL("Calibre UK Ltd")},
	{uL("CVA"), uL("Covia Inc.")},
	{uL("CVI"), uL("Colorado Video, Inc.")},
	{uL("CVP"), uL("Chromatec Video Products Ltd")},
	{uL("CVS"), uL("Clarity Visual Systems")},
	{uL("CWC"), uL("Curtiss-Wright Controls, Inc.")},
	{uL("CWR"), uL("Connectware Inc")},
	{uL("CXT"), uL("Conexant Systems")},
	{uL("CYB"), uL("CyberVision")},
	{uL("CYC"), uL("Cylink Corporation")},
	{uL("CYD"), uL("Cyclades Corporation")},
	{uL("CYL"), uL("Cyberlabs")},
	{uL("CYP"), uL("CYPRESS SEMICONDUCTOR CORPORATION")},
	{uL("CYT"), uL("Cytechinfo Inc")},
	{uL("CYV"), uL("Cyviz AS")},
	{uL("CYW"), uL("Cyberware")},
	{uL("CYX"), uL("Cyrix Corporation")},
	{uL("CZC"), uL("Shenzhen ChuangZhiCheng Technology Co., Ltd.")},
	{uL("CZE"), uL("Carl Zeiss AG")},
	{uL("DAC"), uL("Digital Acoustics Corporation")},
	{uL("DAE"), uL("Digatron Industrie Elektronik GmbH")},
	{uL("DAI"), uL("DAIS SET Ltd.")},
	{uL("DAK"), uL("Daktronics")},
	{uL("DAL"), uL("Digital Audio Labs Inc")},
	{uL("DAN"), uL("Danelec Marine A/S")},
	{uL("DAS"), uL("DAVIS AS")},
	{uL("DAT"), uL("Datel Inc")},
	{uL("DAU"), uL("Daou Tech Inc")},
	{uL("DAV"), uL("Davicom Semiconductor Inc")},
	{uL("DAW"), uL("DA2 Technologies Inc")},
	{uL("DAX"), uL("Data Apex Ltd")},
	{uL("DBD"), uL("Diebold Inc.")},
	{uL("DBI"), uL("DigiBoard Inc")},
	{uL("DBK"), uL("Databook Inc")},
	{uL("DBL"), uL("Doble Engineering Company")},
	{uL("DBN"), uL("DB Networks Inc")},
	{uL("DCA"), uL("Digital Communications Association")},
	{uL("DCC"), uL("Dale Computer Corporation")},
	{uL("DCD"), uL("Datacast LLC")},
	{uL("DCE"), uL("dSPACE GmbH")},
	{uL("DCI"), uL("Concepts Inc")},
	{uL("DCL"), uL("Dynamic Controls Ltd")},
	{uL("DCM"), uL("DCM Data Products")},
	{uL("DCO"), uL("Dialogue Technology Corporation")},
	{uL("DCR"), uL("Decros Ltd")},
	{uL("DCS"), uL("Diamond Computer Systems Inc")},
	{uL("DCT"), uL("Dancall Telecom A/S")},
	{uL("DCV"), uL("Datatronics Technology Inc")},
	{uL("DDA"), uL("DA2 Technologies Corporation")},
	{uL("DDD"), uL("Danka Data Devices")},
	{uL("DDE"), uL("Datasat Digital Entertainment")},
	{uL("DDI"), uL("Data Display AG")},
	{uL("DDS"), uL("Barco, N.V.")},
	{uL("DDT"), uL("Datadesk Technologies Inc")},
	{uL("DDV"), uL("Delta Information Systems, Inc")},
	{uL("DEC"), uL("Digital Equipment Corporation")},
	{uL("DEI"), uL("Deico Electronics")},
	{uL("DEL"), uL("Dell Inc.")},
	{uL("DEN"), uL("Densitron Computers Ltd")},
	{uL("DEX"), uL("idex displays")},
	{uL("DFI"), uL("DFI")},
	{uL("DFK"), uL("SharkTec A/S")},
	{uL("DFT"), uL("DEI Holdings dba Definitive Technology")},
	{uL("DGA"), uL("Digiital Arts Inc")},
	{uL("DGC"), uL("Data General Corporation")},
	{uL("DGI"), uL("DIGI International")},
	{uL("DGK"), uL("DugoTech Co., LTD")},
	{uL("DGP"), uL("Digicorp European sales S.A.")},
	{uL("DGS"), uL("Diagsoft Inc")},
	{uL("DGT"), uL("Dearborn Group Technology")},
	{uL("DHD"), uL("Dension Audio Systems")},
	{uL("DHP"), uL("DH Print")},
	{uL("DHQ"), uL("Quadram")},
	{uL("DHT"), uL("Projectavision Inc")},
	{uL("DIA"), uL("Diadem")},
	{uL("DIG"), uL("Digicom S.p.A.")},
	{uL("DII"), uL("Dataq Instruments Inc")},
	{uL("DIM"), uL("dPict Imaging, Inc.")},
	{uL("DIN"), uL("Daintelecom Co., Ltd")},
	{uL("DIS"), uL("Diseda S.A.")},
	{uL("DIT"), uL("Dragon Information Technology")},
	{uL("DJE"), uL("Capstone Visua lProduct Development")},
	{uL("DJP"), uL("Maygay Machines, Ltd")},
	{uL("DKY"), uL("Datakey Inc")},
	{uL("DLB"), uL("Dolby Laboratories Inc.")},
	{uL("DLC"), uL("Diamond Lane Comm. Corporation")},
	{uL("DLG"), uL("Digital-Logic GmbH")},
	{uL("DLK"), uL("D-Link Systems Inc")},
	{uL("DLL"), uL("Dell Inc")},
	{uL("DLM"), uL("DLOGIC Ltd.")},
	{uL("DLO"), uL("Shenzhen Dlodlo Technologies Co., Ltd.")},
	{uL("DLT"), uL("Digitelec Informatique Park Cadera")},
	{uL("DMB"), uL("Digicom Systems Inc")},
	{uL("DMC"), uL("Dune Microsystems Corporation")},
	{uL("DMG"), uL("Monoprice.Inc")},
	{uL("DMM"), uL("Dimond Multimedia Systems Inc")},
	{uL("DMN"), uL("Dimension Engineering LLC")},
	{uL("DMO"), uL("Data Modul AG")},
	{uL("DMP"), uL("D&M Holdings Inc, Professional Business Company")},
	{uL("DMS"), uL("DOME imaging systems")},
	{uL("DMT"), uL("Distributed Management Task Force, Inc. (DMTF)")},
	{uL("DMV"), uL("NDS Ltd")},
	{uL("DNA"), uL("DNA Enterprises, Inc.")},
	{uL("DNG"), uL("Apache Micro Peripherals Inc")},
	{uL("DNI"), uL("Deterministic Networks Inc.")},
	{uL("DNT"), uL("Dr. Neuhous Telekommunikation GmbH")},
	{uL("DNV"), uL("DiCon")},
	{uL("DOL"), uL("Dolman Technologies Group Inc")},
	{uL("DOM"), uL("Dome Imaging Systems")},
	{uL("DON"), uL("DENON, Ltd.")},
	{uL("DOT"), uL("Dotronic Mikroelektronik GmbH")},
	{uL("DPA"), uL("DigiTalk Pro AV")},
	{uL("DPC"), uL("Delta Electronics Inc")},
	{uL("DPH"), uL("Delphi Automotive LLP")},
	{uL("DPI"), uL("DocuPoint")},
	{uL("DPL"), uL("Digital Projection Limited")},
	{uL("DPM"), uL("ADPM Synthesis sas")},
	{uL("DPN"), uL("Shanghai Lexiang Technology Limited")},
	{uL("DPS"), uL("Digital Processing Systems")},
	{uL("DPT"), uL("DPT")},
	{uL("DPX"), uL("DpiX, Inc.")},
	{uL("DQB"), uL("Datacube Inc")},
	{uL("DRB"), uL("Dr. Bott KG")},
	{uL("DRC"), uL("Data Ray Corp.")},
	{uL("DRD"), uL("DIGITAL REFLECTION INC.")},
	{uL("DRI"), uL("Data Race Inc")},
	{uL("DRS"), uL("DRS Defense Solutions, LLC")},
	{uL("DSA"), uL("Display Solution AG")},
	{uL("DSD"), uL("DS Multimedia Pte Ltd")},
	{uL("DSG"), uL("Disguise Technologies")},
	{uL("DSI"), uL("Digitan Systems Inc")},
	{uL("DSJ"), uL("VR Technology Holdings Limited")},
	{uL("DSM"), uL("DSM Digital Services GmbH")},
	{uL("DSP"), uL("Domain Technology Inc")},
	{uL("DTA"), uL("DELTATEC")},
	{uL("DTC"), uL("DTC Tech Corporation")},
	{uL("DTE"), uL("Dimension Technologies, Inc.")},
	{uL("DTI"), uL("Diversified Technology, Inc.")},
	{uL("DTK"), uL("Dynax Electronics (HK) Ltd")},
	{uL("DTL"), uL("e-Net Inc")},
	{uL("DTN"), uL("Datang Telephone Co")},
	{uL("DTO"), uL("Deutsche Thomson OHG")},
	{uL("DTT"), uL("Design & Test Technology, Inc.")},
	{uL("DTX"), uL("Data Translation")},
	{uL("DUA"), uL("Dosch & Amand GmbH & Company KG")},
	{uL("DUN"), uL("NCR Corporation")},
	{uL("DVD"), uL("Dictaphone Corporation")},
	{uL("DVL"), uL("Devolo AG")},
	{uL("DVS"), uL("Digital Video System")},
	{uL("DVT"), uL("Data Video")},
	{uL("DWE"), uL("Daewoo Electronics Company Ltd")},
	{uL("DXC"), uL("Digipronix Control Systems")},
	{uL("DXD"), uL("DECIMATOR DESIGN PTY LTD")},
	{uL("DXL"), uL("Dextera Labs Inc")},
	{uL("DXP"), uL("Data Expert Corporation")},
	{uL("DXS"), uL("Signet")},
	{uL("DYC"), uL("Dycam Inc")},
	{uL("DYM"), uL("Dymo-CoStar Corporation")},
	{uL("DYN"), uL("Askey Computer Corporation")},
	{uL("DYX"), uL("Dynax Electronics (HK) Ltd")},
	{uL("EAG"), uL("ELTEC Elektronik AG")},
	{uL("EAS"), uL("Evans and Sutherland Computer")},
	{uL("EBH"), uL("Data Price Informatica")},
	{uL("EBS"), uL("EBS Euchner Büro- und Schulsysteme GmbH")},
	{uL("EBT"), uL("HUALONG TECHNOLOGY CO., LTD")},
	{uL("ECA"), uL("Electro Cam Corp.")},
	{uL("ECC"), uL("ESSential Comm. Corporation")},
	{uL("ECH"), uL("EchoStar Corporation")},
	{uL("ECI"), uL("Enciris Technologies")},
	{uL("ECK"), uL("Eugene Chukhlomin Sole Proprietorship, d.b.a.")},
	{uL("ECL"), uL("Excel Company Ltd")},
	{uL("ECM"), uL("E-Cmos Tech Corporation")},
	{uL("ECO"), uL("Echo Speech Corporation")},
	{uL("ECP"), uL("Elecom Company Ltd")},
	{uL("ECS"), uL("Elitegroup Computer Systems Company Ltd")},
	{uL("ECT"), uL("Enciris Technologies")},
	{uL("EDC"), uL("e.Digital Corporation")},
	{uL("EDG"), uL("Electronic-Design GmbH")},
	{uL("EDI"), uL("Edimax Tech. Company Ltd")},
	{uL("EDM"), uL("EDMI")},
	{uL("EDT"), uL("Emerging Display Technologies Corp")},
	{uL("EEE"), uL("ET&T Technology Company Ltd")},
	{uL("EEH"), uL("EEH Datalink GmbH")},
	{uL("EEP"), uL("E.E.P.D. GmbH")},
	{uL("EES"), uL("EE Solutions, Inc.")},
	{uL("EGA"), uL("Elgato Systems LLC")},
	{uL("EGD"), uL("EIZO GmbH Display Technologies")},
	{uL("EGL"), uL("Eagle Technology")},
	{uL("EGN"), uL("Egenera, Inc.")},
	{uL("EGO"), uL("Ergo Electronics")},
	{uL("EHJ"), uL("Epson Research")},
	{uL("EHN"), uL("Enhansoft")},
	{uL("EIC"), uL("Eicon Technology Corporation")},
	{uL("EIN"), uL("Elegant Invention")},
	{uL("EKA"), uL("MagTek Inc.")},
	{uL("EKC"), uL("Eastman Kodak Company")},
	{uL("EKS"), uL("EKSEN YAZILIM")},
	{uL("ELA"), uL("ELAD srl")},
	{uL("ELC"), uL("Electro Scientific Ind")},
	{uL("ELD"), uL("Express Luck, Inc.")},
	{uL("ELE"), uL("Elecom Company Ltd")},
	{uL("ELG"), uL("Elmeg GmbH Kommunikationstechnik")},
	{uL("ELI"), uL("Edsun Laboratories")},
	{uL("ELL"), uL("Electrosonic Ltd")},
	{uL("ELM"), uL("Elmic Systems Inc")},
	{uL("ELO"), uL("Elo TouchSystems Inc")},
	{uL("ELS"), uL("ELSA GmbH")},
	{uL("ELT"), uL("Element Labs, Inc.")},
	{uL("ELU"), uL("Express Industrial, Ltd.")},
	{uL("ELX"), uL("Elonex PLC")},
	{uL("EMB"), uL("Embedded computing inc ltd")},
	{uL("EMC"), uL("eMicro Corporation")},
	{uL("EMD"), uL("Embrionix Design Inc.")},
	{uL("EME"), uL("EMiNE TECHNOLOGY COMPANY, LTD.")},
	{uL("EMG"), uL("EMG Consultants Inc")},
	{uL("EMI"), uL("Ex Machina Inc")},
	{uL("EMK"), uL("Emcore Corporation")},
	{uL("EMO"), uL("ELMO COMPANY, LIMITED")},
	{uL("EMR"), uL("ICC Intelligent Platforms GmbH")},
	{uL("EMU"), uL("Emulex Corporation")},
	{uL("ENC"), uL("Eizo Nanao Corporation")},
	{uL("END"), uL("ENIDAN Technologies Ltd")},
	{uL("ENE"), uL("ENE Technology Inc.")},
	{uL("ENI"), uL("Efficient Networks")},
	{uL("ENS"), uL("Ensoniq Corporation")},
	{uL("ENT"), uL("Enterprise Comm. & Computing Inc")},
	{uL("EON"), uL("Eon Instrumentation, Inc.")},
	{uL("EPC"), uL("Empac")},
	{uL("EPH"), uL("Epiphan Systems Inc. ")},
	{uL("EPI"), uL("Envision Peripherals, Inc")},
	{uL("EPN"), uL("EPiCON Inc.")},
	{uL("EPS"), uL("KEPS")},
	{uL("EQP"), uL("Equipe Electronics Ltd.")},
	{uL("EQX"), uL("Equinox Systems Inc")},
	{uL("ERG"), uL("Ergo System")},
	{uL("ERI"), uL("Ericsson Mobile Communications AB")},
	{uL("ERN"), uL("Ericsson, Inc.")},
	{uL("ERP"), uL("Euraplan GmbH")},
	{uL("ERS"), uL("Eizo Rugged Solutions")},
	{uL("ERT"), uL("Escort Insturments Corporation")},
	{uL("ESA"), uL("Elbit Systems of America")},
	{uL("ESB"), uL("ScioTeq")},
	{uL("ESC"), uL("Eden Sistemas de Computacao S/A")},
	{uL("ESD"), uL("Ensemble Designs, Inc")},
	{uL("ESG"), uL("ELCON Systemtechnik GmbH")},
	{uL("ESI"), uL("Extended Systems, Inc.")},
	{uL("ESK"), uL("ES&S")},
	{uL("ESL"), uL("Esterline Technologies")},
	{uL("ESN"), uL("eSATURNUS")},
	{uL("ESS"), uL("ESS Technology Inc")},
	{uL("EST"), uL("Embedded Solution Technology")},
	{uL("ESY"), uL("E-Systems Inc")},
	{uL("ETC"), uL("Everton Technology Company Ltd")},
	{uL("ETD"), uL("ELAN MICROELECTRONICS CORPORATION")},
	{uL("ETH"), uL("Etherboot Project")},
	{uL("ETI"), uL("Eclipse Tech Inc")},
	{uL("ETK"), uL("eTEK Labs Inc.")},
	{uL("ETL"), uL("Evertz Microsystems Ltd.")},
	{uL("ETS"), uL("Electronic Trade Solutions Ltd")},
	{uL("ETT"), uL("E-Tech Inc")},
	{uL("EUT"), uL("Ericsson Mobile Networks B.V.")},
	{uL("EVE"), uL("Advanced Micro Peripherals Ltd")},
	{uL("EVI"), uL("eviateg GmbH")},
	{uL("EVX"), uL("Everex")},
	{uL("EXA"), uL("Exabyte")},
	{uL("EXC"), uL("Excession Audio")},
	{uL("EXI"), uL("Exide Electronics")},
	{uL("EXN"), uL("RGB Systems, Inc. dba Extron Electronics")},
	{uL("EXP"), uL("Data Export Corporation")},
	{uL("EXR"), uL("Explorer Inc.")},
	{uL("EXT"), uL("Exatech Computadores & Servicos Ltda")},
	{uL("EXX"), uL("Exxact GmbH")},
	{uL("EXY"), uL("Exterity Ltd")},
	{uL("EYE"), uL("eyevis GmbH")},
	{uL("EYF"), uL("eyefactive Gmbh")},
	{uL("EZE"), uL("EzE Technologies")},
	{uL("EZP"), uL("Storm Technology")},
	{uL("FAN"), uL("Fantalooks Co., Ltd.")},
	{uL("FAR"), uL("Farallon Computing")},
	{uL("FBI"), uL("Interface Corporation")},
	{uL("FCB"), uL("Furukawa Electric Company Ltd")},
	{uL("FCG"), uL("First International Computer Ltd")},
	{uL("FCS"), uL("Focus Enhancements, Inc.")},
	{uL("FDC"), uL("Future Domain")},
	{uL("FDD"), uL("Forth Dimension Displays Ltd")},
	{uL("FDI"), uL("Future Designs, Inc.")},
	{uL("FDT"), uL("Fujitsu Display Technologies Corp.")},
	{uL("FDX"), uL("Findex, Inc.")},
	{uL("FEC"), uL("FURUNO ELECTRIC CO., LTD.")},
	{uL("FEL"), uL("Fellowes & Questec")},
	{uL("FEN"), uL("Fen Systems Ltd.")},
	{uL("FER"), uL("Ferranti Int'L")},
	{uL("FFC"), uL("FUJIFILM Corporation")},
	{uL("FFI"), uL("Fairfield Industries")},
	{uL("FGD"), uL("Lisa Draexlmaier GmbH")},
	{uL("FGL"), uL("Fujitsu General Limited.")},
	{uL("FHL"), uL("FHLP")},
	{uL("FIC"), uL("Formosa Industrial Computing Inc")},
	{uL("FIL"), uL("Forefront Int'l Ltd")},
	{uL("FIN"), uL("Finecom Co., Ltd.")},
	{uL("FIR"), uL("Chaplet Systems Inc")},
	{uL("FIS"), uL("FLY-IT Simulators")},
	{uL("FIT"), uL("Feature Integration Technology Inc.")},
	{uL("FJC"), uL("Fujitsu Takamisawa Component Limited")},
	{uL("FJS"), uL("Fujitsu Spain")},
	{uL("FJT"), uL("F.J. Tieman BV")},
	{uL("FLE"), uL("ADTI Media, Inc")},
	{uL("FLI"), uL("Faroudja Laboratories")},
	{uL("FLY"), uL("Butterfly Communications")},
	{uL("FMA"), uL("Fast Multimedia AG")},
	{uL("FMC"), uL("Ford Microelectronics Inc")},
	{uL("FMI"), uL("Fellowes, Inc.")},
	{uL("FML"), uL("Fujitsu Microelect Ltd")},
	{uL("FMZ"), uL("Formoza-Altair")},
	{uL("FNC"), uL("Fanuc LTD")},
	{uL("FNI"), uL("Funai Electric Co., Ltd.")},
	{uL("FOA"), uL("FOR-A Company Limited")},
	{uL("FOK"), uL("Fokus Technologies GmbH")},
	{uL("FOS"), uL("Foss Tecator")},
	{uL("FOV"), uL("FOVE INC")},
	{uL("FOX"), uL("HON HAI PRECISON IND.CO.,LTD.")},
	{uL("FPC"), uL("Fingerprint Cards AB")},
	{uL("FPE"), uL("Fujitsu Peripherals Ltd")},
	{uL("FPS"), uL("Deltec Corporation")},
	{uL("FPX"), uL("Cirel Systemes")},
	{uL("FRC"), uL("Force Computers")},
	{uL("FRD"), uL("Freedom Scientific BLV")},
	{uL("FRE"), uL("Forvus Research Inc")},
	{uL("FRI"), uL("Fibernet Research Inc")},
	{uL("FRO"), uL("FARO Technologies")},
	{uL("FRS"), uL("South Mountain Technologies, LTD")},
	{uL("FSC"), uL("Future Systems Consulting KK")},
	{uL("FSI"), uL("Fore Systems Inc")},
	{uL("FST"), uL("Modesto PC Inc")},
	{uL("FTC"), uL("Futuretouch Corporation")},
	{uL("FTE"), uL("Frontline Test Equipment Inc.")},
	{uL("FTG"), uL("FTG Data Systems")},
	{uL("FTI"), uL("FastPoint Technologies, Inc.")},
	{uL("FTL"), uL("FUJITSU TEN LIMITED")},
	{uL("FTN"), uL("Fountain Technologies Inc")},
	{uL("FTR"), uL("Mediasonic")},
	{uL("FTS"), uL("FocalTech Systems Co., Ltd.")},
	{uL("FTW"), uL("MindTribe Product Engineering, Inc.")},
	{uL("FUJ"), uL("Fujitsu Ltd")},
	{uL("FUL"), uL("Fun Technology Innovation INC.")},
	{uL("FUN"), uL("sisel muhendislik")},
	{uL("FUS"), uL("Fujitsu Siemens Computers GmbH")},
	{uL("FVC"), uL("First Virtual Corporation")},
	{uL("FVX"), uL("C-C-C Group Plc")},
	{uL("FWA"), uL("Attero Tech, LLC")},
	{uL("FWR"), uL("Flat Connections Inc")},
	{uL("FXX"), uL("Fuji Xerox")},
	{uL("FZC"), uL("Founder Group Shenzhen Co.")},
	{uL("FZI"), uL("FZI Forschungszentrum Informatik")},
	{uL("GAC"), uL("GreenArrays, Inc.")},
	{uL("GAG"), uL("Gage Applied Sciences Inc")},
	{uL("GAL"), uL("Galil Motion Control")},
	{uL("GAU"), uL("Gaudi Co., Ltd.")},
	{uL("GBT"), uL("GIGA-BYTE TECHNOLOGY CO., LTD.")},
	{uL("GCC"), uL("GCC Technologies Inc")},
	{uL("GCI"), uL("Gateway Comm. Inc")},
	{uL("GCS"), uL("Grey Cell Systems Ltd")},
	{uL("GDC"), uL("General Datacom")},
	{uL("GDI"), uL("G. Diehl ISDN GmbH")},
	{uL("GDS"), uL("GDS")},
	{uL("GDT"), uL("Vortex Computersysteme GmbH")},
	{uL("GEC"), uL("Gechic Corporation")},
	{uL("GED"), uL("General Dynamics C4 Systems")},
	{uL("GEF"), uL("GE Fanuc Embedded Systems")},
	{uL("GEH"), uL("Abaco Systems, Inc.")},
	{uL("GEM"), uL("Gem Plus")},
	{uL("GEN"), uL("Genesys ATE Inc")},
	{uL("GEO"), uL("GEO Sense")},
	{uL("GER"), uL("GERMANEERS GmbH")},
	{uL("GES"), uL("GES Singapore Pte Ltd")},
	{uL("GET"), uL("Getac Technology Corporation")},
	{uL("GFM"), uL("GFMesstechnik GmbH")},
	{uL("GFN"), uL("Gefen Inc.")},
	{uL("GGL"), uL("Google Inc.")},
	{uL("GGT"), uL("G2TOUCH KOREA")},
	{uL("GIC"), uL("General Inst. Corporation")},
	{uL("GIM"), uL("Guillemont International")},
	{uL("GIP"), uL("GI Provision Ltd")},
	{uL("GIS"), uL("AT&T Global Info Solutions")},
	{uL("GJN"), uL("Grand Junction Networks")},
	{uL("GLD"), uL("Goldmund - Digital Audio SA")},
	{uL("GLE"), uL("AD electronics")},
	{uL("GLM"), uL("Genesys Logic")},
	{uL("GLS"), uL("Gadget Labs LLC")},
	{uL("GMK"), uL("GMK Electronic Design GmbH")},
	{uL("GML"), uL("General Information Systems")},
	{uL("GMM"), uL("GMM Research Inc")},
	{uL("GMN"), uL("GEMINI 2000 Ltd")},
	{uL("GMX"), uL("GMX Inc")},
	{uL("GND"), uL("Gennum Corporation")},
	{uL("GNN"), uL("GN Nettest Inc")},
	{uL("GNZ"), uL("Gunze Ltd")},
	{uL("GOE"), uL("GOEPEL electronic GmbH")},
	{uL("GPR"), uL("GoPro, Inc.")},
	{uL("GRA"), uL("Graphica Computer")},
	{uL("GRE"), uL("GOLD RAIN ENTERPRISES CORP.")},
	{uL("GRH"), uL("Granch Ltd")},
	{uL("GRM"), uL("Garmin International")},
	{uL("GRV"), uL("Advanced Gravis")},
	{uL("GRY"), uL("Robert Gray Company")},
	{uL("GSB"), uL("NIPPONDENCHI CO,.LTD")},
	{uL("GSC"), uL("General Standards Corporation")},
	{uL("GSM"), uL("Goldstar Company Ltd")},
	{uL("GSN"), uL("Grandstream Networks, Inc.")},
	{uL("GST"), uL("Graphic SystemTechnology")},
	{uL("GSY"), uL("Grossenbacher Systeme AG")},
	{uL("GTC"), uL("Graphtec Corporation")},
	{uL("GTI"), uL("Goldtouch")},
	{uL("GTK"), uL("G-Tech Corporation")},
	{uL("GTM"), uL("Garnet System Company Ltd")},
	{uL("GTS"), uL("Geotest Marvin Test Systems Inc")},
	{uL("GTT"), uL("General Touch Technology Co., Ltd.")},
	{uL("GUD"), uL("Guntermann & Drunck GmbH")},
	{uL("GUZ"), uL("Guzik Technical Enterprises")},
	{uL("GVC"), uL("GVC Corporation")},
	{uL("GVL"), uL("Global Village Communication")},
	{uL("GWI"), uL("GW Instruments")},
	{uL("GWK"), uL("Gateworks Corporation")},
	{uL("GWY"), uL("Gateway 2000")},
	{uL("GZE"), uL("GUNZE Limited")},
	{uL("HAE"), uL("Haider electronics")},
	{uL("HAI"), uL("Haivision Systems Inc.")},
	{uL("HAL"), uL("Halberthal")},
	{uL("HAN"), uL("Hanchang System Corporation")},
	{uL("HAR"), uL("Harris Corporation")},
	{uL("HAY"), uL("Hayes Microcomputer Products Inc")},
	{uL("HCA"), uL("DAT")},
	{uL("HCE"), uL("Hitachi Consumer Electronics Co., Ltd")},
	{uL("HCL"), uL("HCL America Inc")},
	{uL("HCM"), uL("HCL Peripherals")},
	{uL("HCP"), uL("Hitachi Computer Products Inc")},
	{uL("HCW"), uL("Hauppauge Computer Works Inc")},
	{uL("HDC"), uL("HardCom Elektronik & Datateknik")},
	{uL("HDI"), uL("HD-INFO d.o.o.")},
	{uL("HDV"), uL("Holografika kft.")},
	{uL("HEC"), uL("Hisense Electric Co., Ltd.")},
	{uL("HEL"), uL("Hitachi Micro Systems Europe Ltd")},
	{uL("HER"), uL("Ascom Business Systems")},
	{uL("HET"), uL("HETEC Datensysteme GmbH")},
	{uL("HHC"), uL("HIRAKAWA HEWTECH CORP.")},
	{uL("HHI"), uL("Fraunhofer Heinrich-Hertz-Institute")},
	{uL("HHT"), uL("Hitevision Group")},
	{uL("HIB"), uL("Hibino Corporation")},
	{uL("HIC"), uL("Hitachi Information Technology Co., Ltd.")},
	{uL("HII"), uL("Harman International Industries, Inc")},
	{uL("HIK"), uL("Hikom Co., Ltd.")},
	{uL("HIL"), uL("Hilevel Technology")},
	{uL("HIQ"), uL("Kaohsiung Opto Electronics Americas, Inc.")},
	{uL("HIS"), uL("Hope Industrial Systems, Inc.")},
	{uL("HIT"), uL("Hitachi America Ltd")},
	{uL("HJI"), uL("Harris & Jeffries Inc")},
	{uL("HKA"), uL("HONKO MFG. CO., LTD.")},
	{uL("HKC"), uL("HKC OVERSEAS LIMITED")},
	{uL("HKG"), uL("Josef Heim KG")},
	{uL("HLG"), uL("China Hualu Group Co., Ltd.")},
	{uL("HMC"), uL("Hualon Microelectric Corporation")},
	{uL("HMK"), uL("hmk Daten-System-Technik BmbH")},
	{uL("HMX"), uL("HUMAX Co., Ltd.")},
	{uL("HNS"), uL("Hughes Network Systems")},
	{uL("HOB"), uL("HOB Electronic GmbH")},
	{uL("HOE"), uL("Hosiden Corporation")},
	{uL("HOL"), uL("Holoeye Photonics AG")},
	{uL("HON"), uL("Sonitronix")},
	{uL("HPA"), uL("Zytor Communications")},
	{uL("HPC"), uL("Hewlett-Packard Co.")},
	{uL("HPD"), uL("Hewlett Packard")},
	{uL("HPE"), uL("Hewlett Packard Enterprise")},
	{uL("HPI"), uL("Headplay, Inc.")},
	{uL("HPK"), uL("HAMAMATSU PHOTONICS K.K.")},
	{uL("HPN"), uL("HP Inc.")},
	{uL("HPQ"), uL("Hewlett-Packard Co.")},
	{uL("HPR"), uL("H.P.R. Electronics GmbH")},
	{uL("HRC"), uL("Hercules")},
	{uL("HRE"), uL("Qingdao Haier Electronics Co., Ltd.")},
	{uL("HRI"), uL("Hall Research")},
	{uL("HRL"), uL("Herolab GmbH")},
	{uL("HRS"), uL("Harris Semiconductor")},
	{uL("HRT"), uL("HERCULES")},
	{uL("HSC"), uL("Hagiwara Sys-Com Company Ltd")},
	{uL("HSD"), uL("HannStar Display Corp")},
	{uL("HSM"), uL("AT&T Microelectronics")},
	{uL("HSN"), uL("Hansung Co., Ltd")},
	{uL("HSP"), uL("HannStar Display Corp")},
	{uL("HST"), uL("Horsent Technology Co., Ltd.")},
	{uL("HTC"), uL("Hitachi Ltd")},
	{uL("HTI"), uL("Hampshire Company, Inc.")},
	{uL("HTK"), uL("Holtek Microelectronics Inc")},
	{uL("HTL"), uL("HTBLuVA Mödling")},
	{uL("HTR"), uL("Shenzhen ZhuoYi HengTong Computer Technology Limited")},
	{uL("HTX"), uL("Hitex Systementwicklung GmbH")},
	{uL("HUB"), uL("GAI-Tronics, A Hubbell Company")},
	{uL("HUK"), uL("Hoffmann + Krippner GmbH")},
	{uL("HUM"), uL("IMP Electronics Ltd.")},
	{uL("HVR"), uL("HTC Corportation")},
	{uL("HWA"), uL("Harris Canada Inc")},
	{uL("HWC"), uL("DBA Hans Wedemeyer")},
	{uL("HWD"), uL("Highwater Designs Ltd")},
	{uL("HWP"), uL("Hewlett Packard")},
	{uL("HWV"), uL("Huawei Technologies Co., Inc.")},
	{uL("HXM"), uL("Hexium Ltd.")},
	{uL("HYC"), uL("Hypercope Gmbh Aachen")},
	{uL("HYD"), uL("Hydis Technologies.Co.,LTD")},
	{uL("HYL"), uL("Shanghai Chai Ming Huang Info&Tech Co, Ltd")},
	{uL("HYO"), uL("HYC CO., LTD.")},
	{uL("HYP"), uL("Hyphen Ltd")},
	{uL("HYR"), uL("Hypertec Pty Ltd")},
	{uL("HYT"), uL("Heng Yu Technology (HK) Limited")},
	{uL("HYV"), uL("Hynix Semiconductor")},
	{uL("IAD"), uL("IAdea Corporation")},
	{uL("IAF"), uL("Institut f r angewandte Funksystemtechnik GmbH")},
	{uL("IAI"), uL("Integration Associates, Inc.")},
	{uL("IAT"), uL("IAT Germany GmbH")},
	{uL("IBC"), uL("Integrated Business Systems")},
	{uL("IBI"), uL("INBINE.CO.LTD")},
	{uL("IBM"), uL("IBM Brasil")},
	{uL("IBP"), uL("IBP Instruments GmbH")},
	{uL("IBR"), uL("IBR GmbH")},
	{uL("ICA"), uL("ICA Inc")},
	{uL("ICC"), uL("BICC Data Networks Ltd")},
	{uL("ICD"), uL("ICD Inc")},
	{uL("ICE"), uL("IC Ensemble")},
	{uL("ICI"), uL("Infotek Communication Inc")},
	{uL("ICM"), uL("Intracom SA")},
	{uL("ICN"), uL("Sanyo Icon")},
	{uL("ICO"), uL("Intel Corp")},
	{uL("ICP"), uL("ICP Electronics, Inc./iEi Technology Corp.")},
	{uL("ICR"), uL("Icron")},
	{uL("ICS"), uL("Integrated Circuit Systems")},
	{uL("ICV"), uL("Inside Contactless")},
	{uL("ICX"), uL("ICCC A/S")},
	{uL("IDC"), uL("International Datacasting Corporation")},
	{uL("IDE"), uL("IDE Associates")},
	{uL("IDK"), uL("IDK Corporation")},
	{uL("IDN"), uL("Idneo Technologies")},
	{uL("IDO"), uL("IDEO Product Development")},
	{uL("IDP"), uL("Integrated Device Technology, Inc.")},
	{uL("IDS"), uL("Interdigital Sistemas de Informacao")},
	{uL("IDT"), uL("International Display Technology")},
	{uL("IDX"), uL("IDEXX Labs")},
	{uL("IEC"), uL("Interlace Engineering Corporation")},
	{uL("IEE"), uL("IEE")},
	{uL("IEI"), uL("Interlink Electronics")},
	{uL("IFS"), uL("In Focus Systems Inc")},
	{uL("IFT"), uL("Informtech")},
	{uL("IFX"), uL("Infineon Technologies AG")},
	{uL("IFZ"), uL("Infinite Z")},
	{uL("IGC"), uL("Intergate Pty Ltd")},
	{uL("IGM"), uL("IGM Communi")},
	{uL("IHE"), uL("InHand Electronics")},
	{uL("IIC"), uL("ISIC Innoscan Industrial Computers A/S")},
	{uL("III"), uL("Intelligent Instrumentation")},
	{uL("IIN"), uL("IINFRA Co., Ltd")},
	{uL("IIT"), uL("Informatik Information Technologies")},
	{uL("IKE"), uL("Ikegami Tsushinki Co. Ltd.")},
	{uL("IKS"), uL("Ikos Systems Inc")},
	{uL("ILC"), uL("Image Logic Corporation")},
	{uL("ILS"), uL("Innotech Corporation")},
	{uL("IMA"), uL("Imagraph")},
	{uL("IMB"), uL("ART s.r.l.")},
	{uL("IMC"), uL("IMC Networks")},
	{uL("IMD"), uL("ImasDe Canarias S.A.")},
	{uL("IME"), uL("Imagraph")},
	{uL("IMF"), uL("Immersive Audio Technologies France")},
	{uL("IMG"), uL("IMAGENICS Co., Ltd.")},
	{uL("IMI"), uL("International Microsystems Inc")},
	{uL("IMM"), uL("Immersion Corporation")},
	{uL("IMN"), uL("Impossible Production")},
	{uL("IMP"), uL("Impinj")},
	{uL("IMT"), uL("Inmax Technology Corporation")},
	{uL("INA"), uL("Inventec Corporation")},
	{uL("INC"), uL("Home Row Inc")},
	{uL("IND"), uL("ILC")},
	{uL("INE"), uL("Inventec Electronics (M) Sdn. Bhd.")},
	{uL("INF"), uL("Inframetrics Inc")},
	{uL("ING"), uL("Integraph Corporation")},
	{uL("INI"), uL("Initio Corporation")},
	{uL("INK"), uL("Indtek Co., Ltd.")},
	{uL("INL"), uL("InnoLux Display Corporation")},
	{uL("INM"), uL("InnoMedia Inc")},
	{uL("INN"), uL("Innovent Systems, Inc.")},
	{uL("INO"), uL("Innolab Pte Ltd")},
	{uL("INP"), uL("Interphase Corporation")},
	{uL("INS"), uL("Ines GmbH")},
	{uL("INT"), uL("Interphase Corporation")},
	{uL("inu"), uL("Inovatec S.p.A.")},
	{uL("INV"), uL("Inviso, Inc.")},
	{uL("INX"), uL("Communications Supply Corporation (A division of WESCO)")},
	{uL("INZ"), uL("Best Buy")},
	{uL("IOA"), uL("CRE Technology Corporation")},
	{uL("IOC"), uL("Guangxi Century Innovation Display Electronics Co., Ltd")},
	{uL("IOD"), uL("I-O Data Device Inc")},
	{uL("IOM"), uL("Iomega")},
	{uL("ION"), uL("Inside Out Networks")},
	{uL("IOS"), uL("i-O Display System")},
	{uL("IOT"), uL("I/OTech Inc")},
	{uL("IPC"), uL("IPC Corporation")},
	{uL("IPD"), uL("Industrial Products Design, Inc.")},
	{uL("IPI"), uL("Intelligent Platform Management Interface (IPMI) forum (Intel, HP, NEC, Dell)")},
	{uL("IPM"), uL("IPM Industria Politecnica Meridionale SpA")},
	{uL("IPN"), uL("Performance Technologies")},
	{uL("IPP"), uL("IP Power Technologies GmbH")},
	{uL("IPQ"), uL("IP3 Technology Ltd.")},
	{uL("IPR"), uL("Ithaca Peripherals")},
	{uL("IPS"), uL("IPS, Inc. (Intellectual Property Solutions, Inc.)")},
	{uL("IPT"), uL("International Power Technologies")},
	{uL("IPW"), uL("IPWireless, Inc")},
	{uL("IQI"), uL("IneoQuest Technologies, Inc")},
	{uL("IQT"), uL("IMAGEQUEST Co., Ltd")},
	{uL("IRD"), uL("Irdata")},
	{uL("ISA"), uL("Symbol Technologies")},
	{uL("ISC"), uL("Id3 Semiconductors")},
	{uL("ISG"), uL("Insignia Solutions Inc")},
	{uL("ISI"), uL("Interface Solutions")},
	{uL("ISL"), uL("Isolation Systems")},
	{uL("ISM"), uL("Image Stream Medical")},
	{uL("ISP"), uL("IntreSource Systems Pte Ltd")},
	{uL("ISR"), uL("INSIS Co., LTD.")},
	{uL("ISS"), uL("ISS Inc")},
	{uL("IST"), uL("Intersolve Technologies")},
	{uL("ISY"), uL("International Integrated Systems,Inc.(IISI)")},
	{uL("ITA"), uL("Itausa Export North America")},
	{uL("ITC"), uL("Intercom Inc")},
	{uL("ITD"), uL("Internet Technology Corporation")},
	{uL("ITE"), uL("Integrated Tech Express Inc")},
	{uL("ITI"), uL("VanErum Group")},
	{uL("ITK"), uL("ITK Telekommunikation AG")},
	{uL("ITL"), uL("Inter-Tel")},
	{uL("ITM"), uL("ITM inc.")},
	{uL("ITN"), uL("The NTI Group")},
	{uL("ITP"), uL("IT-PRO Consulting und Systemhaus GmbH")},
	{uL("ITR"), uL("Infotronic America, Inc.")},
	{uL("ITS"), uL("IDTECH")},
	{uL("ITT"), uL("I&T Telecom.")},
	{uL("ITX"), uL("integrated Technology Express Inc")},
	{uL("IUC"), uL("ICSL")},
	{uL("IVI"), uL("Intervoice Inc")},
	{uL("IVM"), uL("Iiyama North America")},
	{uL("IVR"), uL("Inlife-Handnet Co., Ltd.")},
	{uL("IVS"), uL("Intevac Photonics Inc.")},
	{uL("IWR"), uL("Icuiti Corporation")},
	{uL("IWX"), uL("Intelliworxx, Inc.")},
	{uL("IXD"), uL("Intertex Data AB")},
	{uL("IXN"), uL("Shenzhen Inet Mobile Internet Technology Co., LTD")},
	{uL("JAC"), uL("Astec Inc")},
	{uL("JAE"), uL("Japan Aviation Electronics Industry, Limited")},
	{uL("JAS"), uL("Janz Automationssysteme AG")},
	{uL("JAT"), uL("Jaton Corporation")},
	{uL("JAZ"), uL("Carrera Computer Inc")},
	{uL("JCE"), uL("Jace Tech Inc")},
	{uL("JDI"), uL("Japan Display Inc.")},
	{uL("JDL"), uL("Japan Digital Laboratory Co.,Ltd.")},
	{uL("JEM"), uL("Japan E.M.Solutions Co., Ltd.")},
	{uL("JEN"), uL("N-Vision")},
	{uL("JET"), uL("JET POWER TECHNOLOGY CO., LTD.")},
	{uL("JFX"), uL("Jones Futurex Inc")},
	{uL("JGD"), uL("University College")},
	{uL("JIC"), uL("Jaeik Information & Communication Co., Ltd.")},
	{uL("JKC"), uL("JVC KENWOOD Corporation")},
	{uL("JMT"), uL("Micro Technical Company Ltd")},
	{uL("JPC"), uL("JPC Technology Limited")},
	{uL("JPW"), uL("Wallis Hamilton Industries")},
	{uL("JQE"), uL("CNet Technical Inc")},
	{uL("JSD"), uL("JS DigiTech, Inc")},
	{uL("JSI"), uL("Jupiter Systems, Inc.")},
	{uL("JSK"), uL("SANKEN ELECTRIC CO., LTD")},
	{uL("JTS"), uL("JS Motorsports")},
	{uL("JTY"), uL("jetway security micro,inc")},
	{uL("JUK"), uL("Janich & Klass Computertechnik GmbH")},
	{uL("JUP"), uL("Jupiter Systems")},
	{uL("JVC"), uL("JVC")},
	{uL("JWD"), uL("Video International Inc.")},
	{uL("JWL"), uL("Jewell Instruments, LLC")},
	{uL("JWS"), uL("JWSpencer & Co.")},
	{uL("JWY"), uL("Jetway Information Co., Ltd")},
	{uL("KAR"), uL("Karna")},
	{uL("KBI"), uL("Kidboard Inc")},
	{uL("KBL"), uL("Kobil Systems GmbH")},
	{uL("KCD"), uL("Chunichi Denshi Co.,LTD.")},
	{uL("KCL"), uL("Keycorp Ltd")},
	{uL("KDE"), uL("KDE")},
	{uL("KDK"), uL("Kodiak Tech")},
	{uL("KDM"), uL("Korea Data Systems Co., Ltd.")},
	{uL("KDS"), uL("KDS USA")},
	{uL("KDT"), uL("KDDI Technology Corporation")},
	{uL("KEC"), uL("Kyushu Electronics Systems Inc")},
	{uL("KEM"), uL("Kontron Embedded Modules GmbH")},
	{uL("KES"), uL("Kesa Corporation")},
	{uL("KEU"), uL("Kontron Europe GmbH")},
	{uL("KEY"), uL("Key Tech Inc")},
	{uL("KFC"), uL("SCD Tech")},
	{uL("KFE"), uL("Komatsu Forest")},
	{uL("KFX"), uL("Kofax Image Products")},
	{uL("KGI"), uL("Klipsch Group, Inc")},
	{uL("KGL"), uL("KEISOKU GIKEN Co.,Ltd.")},
	{uL("KIO"), uL("Kionix, Inc.")},
	{uL("KIS"), uL("KiSS Technology A/S")},
	{uL("KMC"), uL("Mitsumi Company Ltd")},
	{uL("KME"), uL("KIMIN Electronics Co., Ltd.")},
	{uL("KML"), uL("Kensington Microware Ltd")},
	{uL("KMR"), uL("Kramer Electronics Ltd. International")},
	{uL("KNC"), uL("Konica corporation")},
	{uL("KNX"), uL("Nutech Marketing PTL")},
	{uL("KOB"), uL("Kobil Systems GmbH")},
	{uL("KOD"), uL("Eastman Kodak Company")},
	{uL("KOE"), uL("KOLTER ELECTRONIC")},
	{uL("KOL"), uL("Kollmorgen Motion Technologies Group")},
	{uL("KOM"), uL("Kontron GmbH")},
	{uL("KOP"), uL("Kopin Corporation")},
	{uL("KOU"), uL("KOUZIRO Co.,Ltd.")},
	{uL("KOW"), uL("KOWA Company,LTD.")},
	{uL("KPC"), uL("King Phoenix Company")},
	{uL("KPT"), uL("TPK Holding Co., Ltd")},
	{uL("KRL"), uL("Krell Industries Inc.")},
	{uL("KRM"), uL("Kroma Telecom")},
	{uL("KRY"), uL("Kroy LLC")},
	{uL("KSC"), uL("Kinetic Systems Corporation")},
	{uL("KSG"), uL("KUPA China Shenzhen Micro Technology Co., Ltd. Gold Institute")},
	{uL("KSL"), uL("Karn Solutions Ltd.")},
	{uL("KSX"), uL("King Tester Corporation")},
	{uL("KTC"), uL("Kingston Tech Corporation")},
	{uL("KTD"), uL("Takahata Electronics Co.,Ltd.")},
	{uL("KTE"), uL("K-Tech")},
	{uL("KTG"), uL("Kayser-Threde GmbH")},
	{uL("KTI"), uL("Konica Technical Inc")},
	{uL("KTK"), uL("Key Tronic Corporation")},
	{uL("KTN"), uL("Katron Tech Inc")},
	{uL("KTS"), uL("Kyokko Communication System Co., Ltd.")},
	{uL("KUR"), uL("Kurta Corporation")},
	{uL("KVA"), uL("Kvaser AB")},
	{uL("KVX"), uL("KeyView")},
	{uL("KWD"), uL("Kenwood Corporation")},
	{uL("KYC"), uL("Kyocera Corporation")},
	{uL("KYE"), uL("KYE Syst Corporation")},
	{uL("KYK"), uL("Samsung Electronics America Inc")},
	{uL("KYN"), uL("KEYENCE CORPORATION")},
	{uL("KZI"), uL("K-Zone International co. Ltd.")},
	{uL("KZN"), uL("K-Zone International")},
	{uL("LAB"), uL("ACT Labs Ltd")},
	{uL("LAC"), uL("LaCie")},
	{uL("LAF"), uL("Microline")},
	{uL("LAG"), uL("Laguna Systems")},
	{uL("LAN"), uL("Sodeman Lancom Inc")},
	{uL("LAS"), uL("LASAT Comm. A/S")},
	{uL("LAV"), uL("Lava Computer MFG Inc")},
	{uL("LBO"), uL("Lubosoft")},
	{uL("LCC"), uL("LCI")},
	{uL("LCD"), uL("Toshiba Matsushita Display Technology Co., Ltd")},
	{uL("LCE"), uL("La Commande Electronique")},
	{uL("LCI"), uL("Lite-On Communication Inc")},
	{uL("LCM"), uL("Latitude Comm.")},
	{uL("LCN"), uL("LEXICON")},
	{uL("LCP"), uL("Silent Power Electronics GmbH")},
	{uL("LCS"), uL("Longshine Electronics Company")},
	{uL("LCT"), uL("Labcal Technologies")},
	{uL("LDN"), uL("Laserdyne Technologies")},
	{uL("LDT"), uL("LogiDataTech Electronic GmbH")},
	{uL("LEC"), uL("Lectron Company Ltd")},
	{uL("LED"), uL("Long Engineering Design Inc")},
	{uL("LEG"), uL("Legerity, Inc")},
	{uL("LEN"), uL("Lenovo Group Limited")},
	{uL("LEO"), uL("First International Computer Inc")},
	{uL("LEX"), uL("Lexical Ltd")},
	{uL("LGC"), uL("Logic Ltd")},
	{uL("LGI"), uL("Logitech Inc")},
	{uL("LGS"), uL("LG Semicom Company Ltd")},
	{uL("LGX"), uL("Lasergraphics, Inc.")},
	{uL("LHA"), uL("Lars Haagh ApS")},
	{uL("LHC"), uL("Beihai Century Joint Innovation Technology Co.,Ltd")},
	{uL("LHE"), uL("Lung Hwa Electronics Company Ltd")},
	{uL("LHT"), uL("Lighthouse Technologies Limited")},
	{uL("LIN"), uL("Lenovo Beijing Co. Ltd.")},
	{uL("LIP"), uL("Linked IP GmbH")},
	{uL("LIS"), uL("Life is Style Inc.")},
	{uL("LIT"), uL("Lithics Silicon Technology")},
	{uL("LJX"), uL("Datalogic Corporation")},
	{uL("LKM"), uL("Likom Technology Sdn. Bhd.")},
	{uL("LLL"), uL("L-3 Communications")},
	{uL("LMG"), uL("Lucent Technologies")},
	{uL("LMI"), uL("Lexmark Int'l Inc")},
	{uL("LMP"), uL("Leda Media Products")},
	{uL("LMT"), uL("Laser Master")},
	{uL("LND"), uL("Land Computer Company Ltd")},
	{uL("LNK"), uL("Link Tech Inc")},
	{uL("LNR"), uL("Linear Systems Ltd.")},
	{uL("LNT"), uL("LANETCO International")},
	{uL("LNV"), uL("Lenovo")},
	{uL("LNX"), uL("The Linux Foundation")},
	{uL("LOC"), uL("Locamation B.V.")},
	{uL("LOE"), uL("Loewe Opta GmbH")},
	{uL("LOG"), uL("Logicode Technology Inc")},
	{uL("LOL"), uL("Litelogic Operations Ltd")},
	{uL("LPE"), uL("El-PUSK Co., Ltd.")},
	{uL("LPI"), uL("Design Technology")},
	{uL("LPL"), uL("DO NOT USE - LPL")},
	{uL("LSC"), uL("LifeSize Communications")},
	{uL("LSD"), uL("Intersil Corporation")},
	{uL("LSI"), uL("Loughborough Sound Images")},
	{uL("LSJ"), uL("LSI Japan Company Ltd")},
	{uL("LSL"), uL("Logical Solutions")},
	{uL("LSP"), uL("Lightspace Technologies")},
	{uL("LSY"), uL("LSI Systems Inc")},
	{uL("LTC"), uL("Labtec Inc")},
	{uL("LTI"), uL("Jongshine Tech Inc")},
	{uL("LTK"), uL("Lucidity Technology Company Ltd")},
	{uL("LTN"), uL("Litronic Inc")},
	{uL("LTS"), uL("LTS Scale LLC")},
	{uL("LTV"), uL("Leitch Technology International Inc.")},
	{uL("LTW"), uL("Lightware, Inc")},
	{uL("LUC"), uL("Lucent Technologies")},
	{uL("LUM"), uL("Lumagen, Inc.")},
	{uL("LUX"), uL("Luxxell Research Inc")},
	{uL("LVI"), uL("LVI Low Vision International AB")},
	{uL("LWC"), uL("Labway Corporation")},
	{uL("LWR"), uL("Lightware Visual Engineering")},
	{uL("LWW"), uL("Lanier Worldwide")},
	{uL("LXC"), uL("LXCO Technologies AG")},
	{uL("LXN"), uL("Luxeon")},
	{uL("LXS"), uL("ELEA CardWare")},
	{uL("LZX"), uL("Lightwell Company Ltd")},
	{uL("MAC"), uL("MAC System Company Ltd")},
	{uL("MAD"), uL("Xedia Corporation")},
	{uL("MAE"), uL("Maestro Pty Ltd")},
	{uL("MAG"), uL("MAG InnoVision")},
	{uL("MAI"), uL("Mutoh America Inc")},
	{uL("MAL"), uL("Meridian Audio Ltd")},
	{uL("MAN"), uL("LGIC")},
	{uL("MAS"), uL("Mass Inc.")},
	{uL("MAT"), uL("Matsushita Electric Ind. Company Ltd")},
	{uL("MAX"), uL("Rogen Tech Distribution Inc")},
	{uL("MAY"), uL("Maynard Electronics")},
	{uL("MAZ"), uL("MAZeT GmbH")},
	{uL("MBC"), uL("MBC")},
	{uL("MBD"), uL("Microbus PLC")},
	{uL("MBM"), uL("Marshall Electronics")},
	{uL("MBV"), uL("Moreton Bay")},
	{uL("MCA"), uL("American Nuclear Systems Inc")},
	{uL("MCC"), uL("Micro Industries")},
	{uL("MCD"), uL("McDATA Corporation")},
	{uL("MCE"), uL("Metz-Werke GmbH & Co KG")},
	{uL("MCG"), uL("Motorola Computer Group")},
	{uL("MCI"), uL("Micronics Computers")},
	{uL("MCJ"), uL("Medicaroid Corporation")},
	{uL("MCL"), uL("Motorola Communications Israel")},
	{uL("MCM"), uL("Metricom Inc")},
	{uL("MCN"), uL("Micron Electronics Inc")},
	{uL("MCO"), uL("Motion Computing Inc.")},
	{uL("MCP"), uL("Magni Systems Inc")},
	{uL("MCQ"), uL("Mat's Computers")},
	{uL("MCR"), uL("Marina Communicaitons")},
	{uL("MCS"), uL("Micro Computer Systems")},
	{uL("MCT"), uL("Microtec")},
	{uL("MCX"), uL("Millson Custom Solutions Inc.")},
	{uL("MDA"), uL("Media4 Inc")},
	{uL("MDC"), uL("Midori Electronics")},
	{uL("MDD"), uL("MODIS")},
	{uL("MDF"), uL("MILDEF AB")},
	{uL("MDG"), uL("Madge Networks")},
	{uL("MDI"), uL("Micro Design Inc")},
	{uL("MDK"), uL("Mediatek Corporation")},
	{uL("MDO"), uL("Panasonic")},
	{uL("MDR"), uL("Medar Inc")},
	{uL("MDS"), uL("Micro Display Systems Inc")},
	{uL("MDT"), uL("Magus Data Tech")},
	{uL("MDV"), uL("MET Development Inc")},
	{uL("MDX"), uL("MicroDatec GmbH")},
	{uL("MDY"), uL("Microdyne Inc")},
	{uL("MEC"), uL("Mega System Technologies Inc")},
	{uL("MED"), uL("Messeltronik Dresden GmbH")},
	{uL("MEE"), uL("Mitsubishi Electric Engineering Co., Ltd.")},
	{uL("MEG"), uL("Abeam Tech Ltd.")},
	{uL("MEI"), uL("Panasonic Industry Company")},
	{uL("MEJ"), uL("Mac-Eight Co., LTD.")},
	{uL("MEK"), uL("Mediaedge Corporation")},
	{uL("MEL"), uL("Mitsubishi Electric Corporation")},
	{uL("MEN"), uL("MEN Mikroelectronik Nueruberg GmbH")},
	{uL("MEP"), uL("Meld Technology")},
	{uL("MEQ"), uL("Matelect Ltd.")},
	{uL("MET"), uL("Metheus Corporation")},
	{uL("MEU"), uL("MPL AG, Elektronik-Unternehmen")},
	{uL("MEX"), uL("MSC Vertriebs GmbH")},
	{uL("MFG"), uL("MicroField Graphics Inc")},
	{uL("MFI"), uL("Micro Firmware")},
	{uL("MFR"), uL("MediaFire Corp.")},
	{uL("MGA"), uL("Mega System Technologies, Inc.")},
	{uL("MGC"), uL("Mentor Graphics Corporation")},
	{uL("MGE"), uL("Schneider Electric S.A.")},
	{uL("MGL"), uL("M-G Technology Ltd")},
	{uL("MGT"), uL("Megatech R & D Company")},
	{uL("MHQ"), uL("Moxa Inc.")},
	{uL("MIC"), uL("Micom Communications Inc")},
	{uL("MID"), uL("miro Displays")},
	{uL("MII"), uL("Mitec Inc")},
	{uL("MIL"), uL("Marconi Instruments Ltd")},
	{uL("MIM"), uL("Mimio – A Newell Rubbermaid Company")},
	{uL("MIN"), uL("Minicom Digital Signage")},
	{uL("MIP"), uL("micronpc.com")},
	{uL("MIR"), uL("Miro Computer Prod.")},
	{uL("MIS"), uL("Modular Industrial Solutions Inc")},
	{uL("MIT"), uL("MCM Industrial Technology GmbH")},
	{uL("MIV"), uL("MicroImage Video Systems")},
	{uL("MJI"), uL("MARANTZ JAPAN, INC.")},
	{uL("MJS"), uL("MJS Designs")},
	{uL("MKC"), uL("Media Tek Inc.")},
	{uL("MKS"), uL("MK Seiko Co., Ltd.")},
	{uL("MKT"), uL("MICROTEK Inc.")},
	{uL("MKV"), uL("Trtheim Technology")},
	{uL("MLC"), uL("MILCOTS")},
	{uL("MLD"), uL("Deep Video Imaging Ltd")},
	{uL("MLG"), uL("Micrologica AG")},
	{uL("MLI"), uL("McIntosh Laboratory Inc.")},
	{uL("MLL"), uL("Millogic Ltd.")},
	{uL("MLM"), uL("Millennium Engineering Inc")},
	{uL("MLN"), uL("Mark Levinson")},
	{uL("MLP"), uL("Magic Leap")},
	{uL("MLS"), uL("Milestone EPE")},
	{uL("MLT"), uL("Wanlida Group Co., Ltd.")},
	{uL("MLX"), uL("Mylex Corporation")},
	{uL("MMA"), uL("Micromedia AG")},
	{uL("MMD"), uL("Micromed Biotecnologia Ltd")},
	{uL("MMF"), uL("Minnesota Mining and Manufacturing")},
	{uL("MMI"), uL("Multimax")},
	{uL("MMM"), uL("Electronic Measurements")},
	{uL("MMN"), uL("MiniMan Inc")},
	{uL("MMS"), uL("MMS Electronics")},
	{uL("MMT"), uL("MIMO Monitors")},
	{uL("MNC"), uL("Mini Micro Methods Ltd")},
	{uL("MNI"), uL("Marseille, Inc.")},
	{uL("MNL"), uL("Monorail Inc")},
	{uL("MNP"), uL("Microcom")},
	{uL("MOC"), uL("Matrix Orbital Corporation")},
	{uL("MOD"), uL("Modular Technology")},
	{uL("MOM"), uL("Momentum Data Systems")},
	{uL("MOS"), uL("Moses Corporation")},
	{uL("MOT"), uL("Motorola UDS")},
	{uL("MPC"), uL("M-Pact Inc")},
	{uL("MPI"), uL("Mediatrix Peripherals Inc")},
	{uL("MPJ"), uL("Microlab")},
	{uL("MPL"), uL("Maple Research Inst. Company Ltd")},
	{uL("MPN"), uL("Mainpine Limited")},
	{uL("MPS"), uL("mps Software GmbH")},
	{uL("MPV"), uL("Megapixel Visual Realty")},
	{uL("MPX"), uL("Micropix Technologies, Ltd.")},
	{uL("MQP"), uL("MultiQ Products AB")},
	{uL("MRA"), uL("Miranda Technologies Inc")},
	{uL("MRC"), uL("Marconi Simulation & Ty-Coch Way Training")},
	{uL("MRD"), uL("MicroDisplay Corporation")},
	{uL("MRK"), uL("Maruko & Company Ltd")},
	{uL("MRL"), uL("Miratel")},
	{uL("MRO"), uL("Medikro Oy")},
	{uL("MRT"), uL("Merging Technologies")},
	{uL("MSA"), uL("Micro Systemation AB")},
	{uL("MSC"), uL("Mouse Systems Corporation")},
	{uL("MSD"), uL("Datenerfassungs- und Informationssysteme")},
	{uL("MSF"), uL("M-Systems Flash Disk Pioneers")},
	{uL("MSG"), uL("MSI GmbH")},
	{uL("MSH"), uL("Microsoft")},
	{uL("MSI"), uL("Microstep")},
	{uL("MSK"), uL("Megasoft Inc")},
	{uL("MSL"), uL("MicroSlate Inc.")},
	{uL("MSM"), uL("Advanced Digital Systems")},
	{uL("MSP"), uL("Mistral Solutions [P] Ltd.")},
	{uL("MSR"), uL("MASPRO DENKOH Corp.")},
	{uL("MST"), uL("MS Telematica")},
	{uL("MSU"), uL("motorola")},
	{uL("MSV"), uL("Mosgi Corporation")},
	{uL("MSX"), uL("Micomsoft Co., Ltd.")},
	{uL("MSY"), uL("MicroTouch Systems Inc")},
	{uL("MTA"), uL("Meta Watch Ltd")},
	{uL("MTB"), uL("Media Technologies Ltd.")},
	{uL("MTC"), uL("Mars-Tech Corporation")},
	{uL("MTD"), uL("MindTech Display Co. Ltd")},
	{uL("MTE"), uL("MediaTec GmbH")},
	{uL("MTH"), uL("Micro-Tech Hearing Instruments")},
	{uL("MTI"), uL("MaxCom Technical Inc")},
	{uL("MTJ"), uL("MicroTechnica Co.,Ltd.")},
	{uL("MTK"), uL("Microtek International Inc.")},
	{uL("MTL"), uL("Mitel Corporation")},
	{uL("MTM"), uL("Motium")},
	{uL("MTN"), uL("Mtron Storage Technology Co., Ltd.")},
	{uL("MTR"), uL("Mitron computer Inc")},
	{uL("MTS"), uL("Multi-Tech Systems")},
	{uL("MTU"), uL("Mark of the Unicorn Inc")},
	{uL("MTX"), uL("Matrox")},
	{uL("MUD"), uL("Multi-Dimension Institute")},
	{uL("MUK"), uL("Mainpine Limited")},
	{uL("MVD"), uL("Microvitec PLC")},
	{uL("MVI"), uL("Media Vision Inc")},
	{uL("MVM"), uL("SOBO VISION")},
	{uL("MVN"), uL("Meta Company")},
	{uL("MVR"), uL("MediCapture, Inc.")},
	{uL("MVS"), uL("Microvision")},
	{uL("MVX"), uL("COM 1")},
	{uL("MWI"), uL("Multiwave Innovation Pte Ltd")},
	{uL("MWR"), uL("mware")},
	{uL("MWY"), uL("Microway Inc")},
	{uL("MXD"), uL("MaxData Computer GmbH & Co.KG")},
	{uL("MXI"), uL("Macronix Inc")},
	{uL("MXL"), uL("Hitachi Maxell, Ltd.")},
	{uL("MXM"), uL("C&T Solution Inc.")},
	{uL("MXP"), uL("Maxpeed Corporation")},
	{uL("MXT"), uL("Maxtech Corporation")},
	{uL("MXV"), uL("MaxVision Corporation")},
	{uL("MYA"), uL("Monydata")},
	{uL("MYR"), uL("Myriad Solutions Ltd")},
	{uL("MYX"), uL("Micronyx Inc")},
	{uL("NAC"), uL("Ncast Corporation")},
	{uL("NAD"), uL("NAD Electronics")},
	{uL("NAF"), uL("NAFASAE INDIA Pvt. Ltd")},
	{uL("NAK"), uL("Nakano Engineering Co.,Ltd.")},
	{uL("NAL"), uL("Network Alchemy")},
	{uL("NAT"), uL("NaturalPoint Inc.")},
	{uL("NAV"), uL("Navigation Corporation")},
	{uL("NAX"), uL("Naxos Tecnologia")},
	{uL("NBL"), uL("N*Able Technologies Inc")},
	{uL("NBS"), uL("National Key Lab. on ISN")},
	{uL("NBT"), uL("NingBo Bestwinning Technology CO., Ltd")},
	{uL("NCA"), uL("Nixdorf Company")},
	{uL("NCC"), uL("NCR Corporation")},
	{uL("NCE"), uL("Norcent Technology, Inc.")},
	{uL("NCI"), uL("NewCom Inc")},
	{uL("NCL"), uL("NetComm Ltd")},
	{uL("NCP"), uL("Najing CEC Panda FPD Technology CO. ltd")},
	{uL("NCR"), uL("NCR Electronics")},
	{uL("NCS"), uL("Northgate Computer Systems")},
	{uL("NCT"), uL("NEC CustomTechnica, Ltd.")},
	{uL("NDC"), uL("National DataComm Corporaiton")},
	{uL("NDF"), uL("NDF Special Light Products B.V.")},
	{uL("NDI"), uL("National Display Systems")},
	{uL("NDK"), uL("Naitoh Densei CO., LTD.")},
	{uL("NDL"), uL("Network Designers")},
	{uL("NDS"), uL("Nokia Data")},
	{uL("NEC"), uL("NEC Corporation")},
	{uL("NEO"), uL("NEO TELECOM CO.,LTD.")},
	{uL("NES"), uL("INNES")},
	{uL("NET"), uL("Mettler Toledo")},
	{uL("NEU"), uL("NEUROTEC - EMPRESA DE PESQUISA E DESENVOLVIMENTO EM BIOMEDICINA")},
	{uL("NEX"), uL("Nexgen Mediatech Inc.,")},
	{uL("NFC"), uL("BTC Korea Co., Ltd")},
	{uL("NFS"), uL("Number Five Software")},
	{uL("NGC"), uL("Network General")},
	{uL("NGS"), uL("A D S Exports")},
	{uL("NHC"), uL("New H3C Technology Co., Ltd.")},
	{uL("NHT"), uL("Vinci Labs")},
	{uL("NIC"), uL("National Instruments Corporation")},
	{uL("NIS"), uL("Nissei Electric Company")},
	{uL("NIT"), uL("Network Info Technology")},
	{uL("NIX"), uL("Seanix Technology Inc")},
	{uL("NLC"), uL("Next Level Communications")},
	{uL("NME"), uL("Navico, Inc.")},
	{uL("NMP"), uL("Nokia Mobile Phones")},
	{uL("NMS"), uL("Natural Micro System")},
	{uL("NMV"), uL("NEC-Mitsubishi Electric Visual Systems Corporation")},
	{uL("NMX"), uL("Neomagic")},
	{uL("NNC"), uL("NNC")},
	{uL("NOD"), uL("3NOD Digital Technology Co. Ltd.")},
	{uL("NOE"), uL("NordicEye AB")},
	{uL("NOI"), uL("North Invent A/S")},
	{uL("NOK"), uL("Nokia Display Products")},
	{uL("NOR"), uL("Norand Corporation")},
	{uL("NOT"), uL("Not Limited Inc")},
	{uL("NPA"), uL("Arvanics")},
	{uL("NPI"), uL("Network Peripherals Inc")},
	{uL("NRI"), uL("Noritake Itron Corporation")},
	{uL("NRL"), uL("U.S. Naval Research Lab")},
	{uL("NRT"), uL("Beijing Northern Radiantelecom Co.")},
	{uL("NRV"), uL("Taugagreining hf")},
	{uL("NSA"), uL("NeuroSky, Inc.")},
	{uL("NSC"), uL("National Semiconductor Corporation")},
	{uL("NSI"), uL("NISSEI ELECTRIC CO.,LTD")},
	{uL("NSP"), uL("Nspire System Inc.")},
	{uL("NSS"), uL("Newport Systems Solutions")},
	{uL("NST"), uL("Network Security Technology Co")},
	{uL("NTC"), uL("NeoTech S.R.L")},
	{uL("NTI"), uL("New Tech Int'l Company")},
	{uL("NTK"), uL("NewTek")},
	{uL("NTL"), uL("National Transcomm. Ltd")},
	{uL("NTN"), uL("Nuvoton Technology Corporation")},
	{uL("NTR"), uL("N-trig Innovative Technologies, Inc.")},
	{uL("NTS"), uL("Nits Technology Inc.")},
	{uL("NTT"), uL("NTT Advanced Technology Corporation")},
	{uL("NTW"), uL("Networth Inc")},
	{uL("NTX"), uL("Netaccess Inc")},
	{uL("NUG"), uL("NU Technology, Inc.")},
	{uL("NUI"), uL("NU Inc.")},
	{uL("NVC"), uL("NetVision Corporation")},
	{uL("NVD"), uL("Nvidia")},
	{uL("NVI"), uL("NuVision US, Inc.")},
	{uL("NVL"), uL("Novell Inc")},
	{uL("NVO"), uL("Netvio Ltd.")},
	{uL("NVT"), uL("Navatek Engineering Corporation")},
	{uL("NWC"), uL("NW Computer Engineering")},
	{uL("NWL"), uL("Newline Interactive Inc.")},
	{uL("NWP"), uL("NovaWeb Technologies Inc")},
	{uL("NWS"), uL("Newisys, Inc.")},
	{uL("NXC"), uL("NextCom K.K.")},
	{uL("NXG"), uL("Nexgen")},
	{uL("NXP"), uL("NXP Semiconductors bv.")},
	{uL("NXQ"), uL("Nexiq Technologies, Inc.")},
	{uL("NXR"), uL("Nextorage Corporation")},
	{uL("NXS"), uL("Technology Nexus Secure Open Systems AB")},
	{uL("NXT"), uL("NZXT (PNP same EDID)_")},
	{uL("NYC"), uL("Nakayo Relecommunications, Inc.")},
	{uL("OAK"), uL("Oak Tech Inc")},
	{uL("OAS"), uL("Oasys Technology Company")},
	{uL("OBS"), uL("Optibase Technologies")},
	{uL("OCD"), uL("Macraigor Systems Inc")},
	{uL("OCN"), uL("Olfan")},
	{uL("OCS"), uL("Open Connect Solutions")},
	{uL("ODM"), uL("ODME Inc.")},
	{uL("ODR"), uL("Odrac")},
	{uL("OEC"), uL("ORION ELECTRIC CO.,LTD")},
	{uL("OEI"), uL("Optum Engineering Inc.")},
	{uL("OHW"), uL("M-Labs Limited")},
	{uL("OIC"), uL("Option Industrial Computers")},
	{uL("OIM"), uL("Option International")},
	{uL("OIN"), uL("Option International")},
	{uL("OKI"), uL("OKI Electric Industrial Company Ltd")},
	{uL("OLC"), uL("Olicom A/S")},
	{uL("OLD"), uL("Olidata S.p.A.")},
	{uL("OLI"), uL("Olivetti")},
	{uL("OLT"), uL("Olitec S.A.")},
	{uL("OLV"), uL("Olitec S.A.")},
	{uL("OLY"), uL("OLYMPUS CORPORATION")},
	{uL("OMC"), uL("OBJIX Multimedia Corporation")},
	{uL("OMN"), uL("Omnitel")},
	{uL("OMR"), uL("Omron Corporation")},
	{uL("ONE"), uL("Oneac Corporation")},
	{uL("ONK"), uL("ONKYO Corporation")},
	{uL("ONL"), uL("OnLive, Inc")},
	{uL("ONS"), uL("On Systems Inc")},
	{uL("ONW"), uL("OPEN Networks Ltd")},
	{uL("ONX"), uL("SOMELEC Z.I. Du Vert Galanta")},
	{uL("OOS"), uL("OSRAM")},
	{uL("OPC"), uL("Opcode Inc")},
	{uL("OPI"), uL("D.N.S. Corporation")},
	{uL("OPP"), uL("OPPO Digital, Inc.")},
	{uL("OPT"), uL("OPTi Inc")},
	{uL("OPV"), uL("Optivision Inc")},
	{uL("OQI"), uL("Oksori Company Ltd")},
	{uL("ORG"), uL("ORGA Kartensysteme GmbH")},
	{uL("ORI"), uL("OSR Open Systems Resources, Inc.")},
	{uL("ORN"), uL("ORION ELECTRIC CO., LTD.")},
	{uL("OSA"), uL("OSAKA Micro Computer, Inc.")},
	{uL("OSD"), uL("Optical Systems Design Pty Ltd")},
	{uL("OSI"), uL("Open Stack, Inc.")},
	{uL("OSP"), uL("OPTI-UPS Corporation")},
	{uL("OSR"), uL("Oksori Company Ltd")},
	{uL("OTB"), uL("outsidetheboxstuff.com")},
	{uL("OTI"), uL("Orchid Technology")},
	{uL("OTK"), uL("OmniTek")},
	{uL("OTM"), uL("Optoma Corporation          ")},
	{uL("OTT"), uL("OPTO22, Inc.")},
	{uL("OUK"), uL("OUK Company Ltd")},
	{uL("OVR"), uL("Oculus VR, Inc.")},
	{uL("OWL"), uL("Mediacom Technologies Pte Ltd")},
	{uL("OXU"), uL("Oxus Research S.A.")},
	{uL("OYO"), uL("Shadow Systems")},
	{uL("OZC"), uL("OZ Corporation")},
	{uL("OZO"), uL("Tribe Computer Works Inc")},
	{uL("PAC"), uL("Pacific Avionics Corporation")},
	{uL("PAD"), uL("Promotion and Display Technology Ltd.")},
	{uL("PAE"), uL("PreSonus Audio Electronics")},
	{uL("PAK"), uL("Many CNC System Co., Ltd.")},
	{uL("PAM"), uL("Peter Antesberger Messtechnik")},
	{uL("PAN"), uL("The Panda Project")},
	{uL("PAR"), uL("Parallan Comp Inc")},
	{uL("PBI"), uL("Pitney Bowes")},
	{uL("PBL"), uL("Packard Bell Electronics")},
	{uL("PBN"), uL("Packard Bell NEC")},
	{uL("PBV"), uL("Pitney Bowes")},
	{uL("PCA"), uL("Philips BU Add On Card")},
	{uL("PCB"), uL("OCTAL S.A.")},
	{uL("PCC"), uL("PowerCom Technology Company Ltd")},
	{uL("PCG"), uL("First Industrial Computer Inc")},
	{uL("PCI"), uL("Pioneer Computer Inc")},
	{uL("PCK"), uL("PCBANK21")},
	{uL("PCL"), uL("pentel.co.,ltd")},
	{uL("PCM"), uL("PCM Systems Corporation")},
	{uL("PCO"), uL("Performance Concepts Inc.,")},
	{uL("PCP"), uL("Procomp USA Inc")},
	{uL("PCS"), uL("TOSHIBA PERSONAL COMPUTER SYSTEM CORPRATION")},
	{uL("PCT"), uL("PC-Tel Inc")},
	{uL("PCW"), uL("Pacific CommWare Inc")},
	{uL("PCX"), uL("PC Xperten")},
	{uL("PDM"), uL("Psion Dacom Plc.")},
	{uL("PDN"), uL("AT&T Paradyne")},
	{uL("PDR"), uL("Pure Data Inc")},
	{uL("PDS"), uL("PD Systems International Ltd")},
	{uL("PDT"), uL("PDTS - Prozessdatentechnik und Systeme")},
	{uL("PDV"), uL("Prodrive B.V.")},
	{uL("PEC"), uL("POTRANS Electrical Corp.")},
	{uL("PEG"), uL("Pegatron Corporation")},
	{uL("PEI"), uL("PEI Electronics Inc")},
	{uL("PEL"), uL("Primax Electric Ltd")},
	{uL("PEN"), uL("Interactive Computer Products Inc")},
	{uL("PEP"), uL("Peppercon AG")},
	{uL("PER"), uL("Perceptive Signal Technologies")},
	{uL("PET"), uL("Practical Electronic Tools")},
	{uL("PFT"), uL("Telia ProSoft AB")},
	{uL("PGI"), uL("PACSGEAR, Inc.")},
	{uL("PGM"), uL("Paradigm Advanced Research Centre")},
	{uL("PGP"), uL("propagamma kommunikation")},
	{uL("PGS"), uL("Princeton Graphic Systems")},
	{uL("PHC"), uL("Pijnenburg Beheer N.V.")},
	{uL("PHE"), uL("Philips Medical Systems Boeblingen GmbH")},
	{uL("PHI"), uL("DO NOT USE - PHI")},
	{uL("PHL"), uL("Philips Consumer Electronics Company")},
	{uL("PHO"), uL("Photonics Systems Inc.")},
	{uL("PHS"), uL("Philips Communication Systems")},
	{uL("PHY"), uL("Phylon Communications")},
	{uL("PIC"), uL("Picturall Ltd.")},
	{uL("PIE"), uL("Pacific Image Electronics Company Ltd")},
	{uL("PIM"), uL("Prism, LLC")},
	{uL("PIO"), uL("Pioneer Electronic Corporation")},
	{uL("PIR"), uL("Pico Technology Inc.")},
	{uL("PIS"), uL("TECNART CO.,LTD.")},
	{uL("PIX"), uL("Pixie Tech Inc")},
	{uL("PJA"), uL("Projecta")},
	{uL("PJD"), uL("Projectiondesign AS")},
	{uL("PJT"), uL("Pan Jit International Inc.")},
	{uL("PKA"), uL("Acco UK Ltd.")},
	{uL("PLC"), uL("Pro-Log Corporation")},
	{uL("PLF"), uL("Panasonic Avionics Corporation")},
	{uL("PLM"), uL("PROLINK Microsystems Corp.")},
	{uL("PLT"), uL("PT Hartono Istana Teknologi")},
	{uL("PLV"), uL("PLUS Vision Corp.")},
	{uL("PLX"), uL("Parallax Graphics")},
	{uL("PLY"), uL("Polycom Inc.")},
	{uL("PMC"), uL("PMC Consumer Electronics Ltd")},
	{uL("PMD"), uL("TDK USA Corporation")},
	{uL("PMM"), uL("Point Multimedia System")},
	{uL("PMS"), uL("Pabian Embedded Systems")},
	{uL("PMT"), uL("Promate Electronic Co., Ltd.")},
	{uL("PMX"), uL("Photomatrix")},
	{uL("PNG"), uL("Microsoft")},
	{uL("PNL"), uL("Panelview, Inc.")},
	{uL("PNP"), uL("Microsoft")},
	{uL("PNR"), uL("Planar Systems, Inc.")},
	{uL("PNS"), uL("PanaScope")},
	{uL("PNT"), uL("HOYA Corporation PENTAX Lifecare Division")},
	{uL("PNX"), uL("Phoenix Technologies, Ltd.")},
	{uL("POL"), uL("PolyComp (PTY) Ltd.")},
	{uL("PON"), uL("Perpetual Technologies, LLC")},
	{uL("POR"), uL("Portalis LC")},
	{uL("POS"), uL("Positivo Tecnologia S.A.")},
	{uL("POT"), uL("Parrot")},
	{uL("PPC"), uL("Phoenixtec Power Company Ltd")},
	{uL("PPD"), uL("MEPhI")},
	{uL("PPI"), uL("Practical Peripherals")},
	{uL("PPM"), uL("Clinton Electronics Corp.")},
	{uL("PPP"), uL("Purup Prepress AS")},
	{uL("PPR"), uL("PicPro")},
	{uL("PPX"), uL("Perceptive Pixel Inc.")},
	{uL("PQI"), uL("Pixel Qi")},
	{uL("PRA"), uL("PRO/AUTOMATION")},
	{uL("PRC"), uL("PerComm")},
	{uL("PRD"), uL("Praim S.R.L.")},
	{uL("PRF"), uL("Schneider Electric Japan Holdings, Ltd.")},
	{uL("PRG"), uL("The Phoenix Research Group Inc")},
	{uL("PRI"), uL("Priva Hortimation BV")},
	{uL("PRM"), uL("Prometheus")},
	{uL("PRO"), uL("Proteon")},
	{uL("PRP"), uL("UEFI Forum")},
	{uL("PRS"), uL("Leutron Vision")},
	{uL("PRT"), uL("Parade Technologies, Ltd.")},
	{uL("PRX"), uL("Proxima Corporation")},
	{uL("PSA"), uL("Advanced Signal Processing Technologies")},
	{uL("PSC"), uL("Philips Semiconductors")},
	{uL("PSD"), uL("Peus-Systems GmbH")},
	{uL("PSE"), uL("Practical Solutions Pte., Ltd.")},
	{uL("PSI"), uL("PSI-Perceptive Solutions Inc")},
	{uL("PSL"), uL("Perle Systems Limited")},
	{uL("PSM"), uL("Prosum")},
	{uL("PST"), uL("Global Data SA")},
	{uL("PSY"), uL("Prodea Systems Inc.")},
	{uL("PTA"), uL("PAR Tech Inc.")},
	{uL("PTC"), uL("PS Technology Corporation")},
	{uL("PTG"), uL("Cipher Systems Inc")},
	{uL("PTH"), uL("Pathlight Technology Inc")},
	{uL("PTI"), uL("Promise Technology Inc")},
	{uL("PTL"), uL("Pantel Inc")},
	{uL("PTS"), uL("Plain Tree Systems Inc")},
	{uL("PTW"), uL("DO NOT USE - PTW")},
	{uL("PUL"), uL("Pulse-Eight Ltd")},
	{uL("PVC"), uL("DO NOT USE - PVC")},
	{uL("PVG"), uL("Proview Global Co., Ltd")},
	{uL("PVI"), uL("Prime view international Co., Ltd")},
	{uL("PVM"), uL("Penta Studiotechnik GmbH")},
	{uL("PVN"), uL("Pixel Vision")},
	{uL("PVP"), uL("Klos Technologies, Inc.")},
	{uL("PVR"), uL("Pimax Tech. CO., LTD")},
	{uL("PXC"), uL("Phoenix Contact")},
	{uL("PXE"), uL("PIXELA CORPORATION")},
	{uL("PXL"), uL("The Moving Pixel Company")},
	{uL("PXM"), uL("Proxim Inc")},
	{uL("PXN"), uL("PixelNext Inc")},
	{uL("QCC"), uL("QuakeCom Company Ltd")},
	{uL("QCH"), uL("Metronics Inc")},
	{uL("QCI"), uL("Quanta Computer Inc")},
	{uL("QCK"), uL("Quick Corporation")},
	{uL("QCL"), uL("Quadrant Components Inc")},
	{uL("QCP"), uL("Qualcomm Inc")},
	{uL("QDI"), uL("Quantum Data Incorporated")},
	{uL("QDL"), uL("QD Laser, Inc.")},
	{uL("QDM"), uL("Quadram")},
	{uL("QDS"), uL("Quanta Display Inc.")},
	{uL("QFF"), uL("Padix Co., Inc.")},
	{uL("QFI"), uL("Quickflex, Inc")},
	{uL("QLC"), uL("Q-Logic")},
	{uL("QQQ"), uL("Chuomusen Co., Ltd.")},
	{uL("QSC"), uL("QSC, LLC")},
	{uL("QSI"), uL("Quantum Solutions, Inc.")},
	{uL("QTD"), uL("Quantum 3D Inc")},
	{uL("QTH"), uL("Questech Ltd")},
	{uL("QTI"), uL("Quicknet Technologies Inc")},
	{uL("QTM"), uL("Quantum")},
	{uL("QTR"), uL("Qtronix Corporation")},
	{uL("QUA"), uL("Quatographic AG")},
	{uL("QUE"), uL("Questra Consulting")},
	{uL("QVU"), uL("Quartics")},
	{uL("RAC"), uL("Racore Computer Products Inc")},
	{uL("RAD"), uL("Radisys Corporation")},
	{uL("RAI"), uL("Rockwell Automation/Intecolor")},
	{uL("RAN"), uL("Rancho Tech Inc")},
	{uL("RAR"), uL("Raritan, Inc.")},
	{uL("RAS"), uL("RAScom Inc")},
	{uL("RAT"), uL("Rent-A-Tech")},
	{uL("RAY"), uL("Raylar Design, Inc.")},
	{uL("RCE"), uL("Parc d'Activite des Bellevues")},
	{uL("RCH"), uL("Reach Technology Inc")},
	{uL("RCI"), uL("RC International")},
	{uL("RCN"), uL("Radio Consult SRL")},
	{uL("RCO"), uL("Rockwell Collins")},
	{uL("RDI"), uL("Rainbow Displays, Inc.")},
	{uL("RDM"), uL("Tremon Enterprises Company Ltd")},
	{uL("RDN"), uL("RADIODATA GmbH")},
	{uL("RDS"), uL("Radius Inc")},
	{uL("REA"), uL("Real D")},
	{uL("REC"), uL("ReCom")},
	{uL("RED"), uL("Research Electronics Development Inc")},
	{uL("REF"), uL("Reflectivity, Inc.")},
	{uL("REH"), uL("Rehan Electronics Ltd.")},
	{uL("REL"), uL("Reliance Electric Ind Corporation")},
	{uL("REM"), uL("SCI Systems Inc.")},
	{uL("REN"), uL("Renesas Technology Corp.")},
	{uL("RES"), uL("ResMed Pty Ltd")},
	{uL("RET"), uL("Resonance Technology, Inc.")},
	{uL("REV"), uL("Revolution Display, Inc.")},
	{uL("REX"), uL("RATOC Systems, Inc.")},
	{uL("RFI"), uL("RAFI GmbH & Co. KG")},
	{uL("RFX"), uL("Redfox Technologies Inc.")},
	{uL("RGB"), uL("RGB Spectrum")},
	{uL("RGL"), uL("Robertson Geologging Ltd")},
	{uL("RHD"), uL("RightHand Technologies")},
	{uL("RHM"), uL("Rohm Company Ltd")},
	{uL("RHT"), uL("Red Hat, Inc.")},
	{uL("RIC"), uL("RICOH COMPANY, LTD.")},
	{uL("RII"), uL("Racal Interlan Inc")},
	{uL("RIO"), uL("Rios Systems Company Ltd")},
	{uL("RIT"), uL("Ritech Inc")},
	{uL("RIV"), uL("Rivulet Communications")},
	{uL("RJA"), uL("Roland Corporation")},
	{uL("RJS"), uL("Advanced Engineering")},
	{uL("RKC"), uL("Reakin Technolohy Corporation")},
	{uL("RLD"), uL("MEPCO")},
	{uL("RLN"), uL("RadioLAN Inc")},
	{uL("RMC"), uL("Raritan Computer, Inc")},
	{uL("RMP"), uL("Research Machines")},
	{uL("RMS"), uL("Shenzhen Ramos Digital Technology Co., Ltd")},
	{uL("RMT"), uL("Roper Mobile")},
	{uL("RNB"), uL("Rainbow Technologies")},
	{uL("ROB"), uL("Robust Electronics GmbH")},
	{uL("ROH"), uL("Rohm Co., Ltd.")},
	{uL("ROK"), uL("Rockwell International")},
	{uL("ROP"), uL("Roper International Ltd")},
	{uL("ROS"), uL("Rohde & Schwarz")},
	{uL("RPI"), uL("RoomPro Technologies")},
	{uL("RPT"), uL("R.P.T.Intergroups")},
	{uL("RRI"), uL("Radicom Research Inc")},
	{uL("RSC"), uL("PhotoTelesis")},
	{uL("RSH"), uL("ADC-Centre")},
	{uL("RSI"), uL("Rampage Systems Inc")},
	{uL("RSN"), uL("Radiospire Networks, Inc.")},
	{uL("RSQ"), uL("R Squared")},
	{uL("RSR"), uL("Zhong Shan City Richsound Electronic Industrial Ltd.")},
	{uL("RSS"), uL("Rockwell Semiconductor Systems")},
	{uL("RSV"), uL("Ross Video Ltd")},
	{uL("RSX"), uL("Rapid Tech Corporation")},
	{uL("RTC"), uL("Relia Technologies")},
	{uL("RTI"), uL("Rancho Tech Inc")},
	{uL("RTK"), uL("DO NOT USE - RTK")},
	{uL("RTL"), uL("Realtek Semiconductor Company Ltd")},
	{uL("RTS"), uL("Raintree Systems")},
	{uL("RUN"), uL("RUNCO International")},
	{uL("RUP"), uL("Ups Manufactoring s.r.l.")},
	{uL("RVC"), uL("RSI Systems Inc")},
	{uL("RVI"), uL("Realvision Inc")},
	{uL("RVL"), uL("Reveal Computer Prod")},
	{uL("RWC"), uL("Red Wing Corporation")},
	{uL("RXT"), uL("Tectona SoftSolutions (P) Ltd.,")},
	{uL("RZR"), uL("Razer Taiwan Co. Ltd.")},
	{uL("RZS"), uL("Rozsnyó, s.r.o.")},
	{uL("SAA"), uL("Sanritz Automation Co.,Ltd.")},
	{uL("SAE"), uL("Saab Aerotech")},
	{uL("SAG"), uL("Sedlbauer")},
	{uL("SAI"), uL("Sage Inc")},
	{uL("SAK"), uL("Saitek Ltd")},
	{uL("SAM"), uL("Samsung Electric Company")},
	{uL("SAN"), uL("Sanyo Electric Co.,Ltd.")},
	{uL("SAS"), uL("Stores Automated Systems Inc")},
	{uL("SAT"), uL("Shuttle Tech")},
	{uL("SBC"), uL("Shanghai Bell Telephone Equip Mfg Co")},
	{uL("SBD"), uL("Softbed - Consulting & Development Ltd")},
	{uL("SBI"), uL("SMART Technologies Inc.")},
	{uL("SBS"), uL("SBS-or Industrial Computers GmbH")},
	{uL("SBT"), uL("Senseboard Technologies AB")},
	{uL("SCA"), uL("Schneider Consumer Group")},
	{uL("SCB"), uL("SeeCubic B.V.")},
	{uL("SCC"), uL("SORD Computer Corporation")},
	{uL("SCD"), uL("Sanyo Electric Company Ltd")},
	{uL("SCE"), uL("Sun Corporation")},
	{uL("SCG"), uL("Seco S.p.A.")},
	{uL("SCH"), uL("Schlumberger Cards")},
	{uL("SCI"), uL("System Craft")},
	{uL("SCL"), uL("Sigmacom Co., Ltd.")},
	{uL("SCM"), uL("SCM Microsystems Inc")},
	{uL("SCN"), uL("Scanport, Inc.")},
	{uL("SCO"), uL("SORCUS Computer GmbH")},
	{uL("SCP"), uL("Scriptel Corporation")},
	{uL("SCR"), uL("Systran Corporation")},
	{uL("SCS"), uL("Nanomach Anstalt")},
	{uL("SCT"), uL("Smart Card Technology")},
	{uL("SCX"), uL("Socionext Inc.")},
	{uL("SDA"), uL("SAT (Societe Anonyme)")},
	{uL("SDD"), uL("Intrada-SDD Ltd")},
	{uL("SDE"), uL("Sherwood Digital Electronics Corporation")},
	{uL("SDF"), uL("SODIFF E&T CO., Ltd.")},
	{uL("SDH"), uL("Communications Specialies, Inc.")},
	{uL("SDI"), uL("Samtron Displays Inc")},
	{uL("SDK"), uL("SAIT-Devlonics")},
	{uL("SDR"), uL("SDR Systems")},
	{uL("SDS"), uL("SunRiver Data System")},
	{uL("SDT"), uL("Siemens AG")},
	{uL("SDX"), uL("SDX Business Systems Ltd")},
	{uL("SEA"), uL("Seanix Technology Inc.")},
	{uL("SEB"), uL("system elektronik GmbH")},
	{uL("SEC"), uL("Seiko Epson Corporation")},
	{uL("SEE"), uL("SeeColor Corporation")},
	{uL("SEG"), uL("DO NOT USE - SEG")},
	{uL("SEI"), uL("Seitz & Associates Inc")},
	{uL("SEL"), uL("Way2Call Communications")},
	{uL("SEM"), uL("Samsung Electronics Company Ltd")},
	{uL("SEN"), uL("Sencore")},
	{uL("SEO"), uL("SEOS Ltd")},
	{uL("SEP"), uL("SEP Eletronica Ltda.")},
	{uL("SER"), uL("Sony Ericsson Mobile Communications Inc.")},
	{uL("SES"), uL("Session Control LLC")},
	{uL("SET"), uL("SendTek Corporation")},
	{uL("SFL"), uL("Shiftall Inc.")},
	{uL("SFM"), uL("TORNADO Company")},
	{uL("SFT"), uL("Mikroforum Ring 3")},
	{uL("SGC"), uL("Spectragraphics Corporation")},
	{uL("SGD"), uL("Sigma Designs, Inc.")},
	{uL("SGE"), uL("Kansai Electric Company Ltd")},
	{uL("SGI"), uL("Scan Group Ltd")},
	{uL("SGL"), uL("Super Gate Technology Company Ltd")},
	{uL("SGM"), uL("SAGEM")},
	{uL("SGO"), uL("Logos Design A/S")},
	{uL("SGT"), uL("Stargate Technology")},
	{uL("SGW"), uL("Shanghai Guowei Science and Technology Co., Ltd.")},
	{uL("SGX"), uL("Silicon Graphics Inc")},
	{uL("SGZ"), uL("Systec Computer GmbH")},
	{uL("SHC"), uL("ShibaSoku Co., Ltd.")},
	{uL("SHG"), uL("Soft & Hardware development Goldammer GmbH")},
	{uL("SHI"), uL("Jiangsu Shinco Electronic Group Co., Ltd")},
	{uL("SHP"), uL("Sharp Corporation")},
	{uL("SHR"), uL("Digital Discovery")},
	{uL("SHT"), uL("Shin Ho Tech")},
	{uL("SIA"), uL("SIEMENS AG")},
	{uL("SIB"), uL("Sanyo Electric Company Ltd")},
	{uL("SIC"), uL("Sysmate Corporation")},
	{uL("SID"), uL("Seiko Instruments Information Devices Inc")},
	{uL("SIE"), uL("Siemens")},
	{uL("SIG"), uL("Sigma Designs Inc")},
	{uL("SII"), uL("Silicon Image, Inc.")},
	{uL("SIL"), uL("Silicon Laboratories, Inc")},
	{uL("SIM"), uL("S3 Inc")},
	{uL("SIN"), uL("Singular Technology Co., Ltd.")},
	{uL("SIR"), uL("Sirius Technologies Pty Ltd")},
	{uL("SIS"), uL("Silicon Integrated Systems Corporation")},
	{uL("SIT"), uL("Sitintel")},
	{uL("SIU"), uL("Seiko Instruments USA Inc")},
	{uL("SIX"), uL("Zuniq Data Corporation")},
	{uL("SJE"), uL("Sejin Electron Inc")},
	{uL("SKD"), uL("Schneider & Koch")},
	{uL("SKG"), uL("Shenzhen KTC Technology Group")},
	{uL("SKI"), uL("LLC SKTB 'SKIT'")},
	{uL("SKM"), uL("Guangzhou Teclast Information Technology Limited")},
	{uL("SKT"), uL("Samsung Electro-Mechanics Company Ltd")},
	{uL("SKW"), uL("Skyworth")},
	{uL("SKY"), uL("SKYDATA S.P.A.")},
	{uL("SLA"), uL("Systeme Lauer GmbH&Co KG")},
	{uL("SLB"), uL("Shlumberger Ltd")},
	{uL("SLC"), uL("Syslogic Datentechnik AG")},
	{uL("SLF"), uL("StarLeaf")},
	{uL("SLH"), uL("Silicon Library Inc.")},
	{uL("SLI"), uL("Symbios Logic Inc")},
	{uL("SLK"), uL("Silitek Corporation")},
	{uL("SLM"), uL("Solomon Technology Corporation")},
	{uL("SLR"), uL("Schlumberger Technology Corporate")},
	{uL("SLS"), uL("Schnick-Schnack-Systems GmbH")},
	{uL("SLT"), uL("Salt Internatioinal Corp.")},
	{uL("SLX"), uL("Specialix")},
	{uL("SMA"), uL("SMART Modular Technologies")},
	{uL("SMB"), uL("Schlumberger")},
	{uL("SMC"), uL("Standard Microsystems Corporation")},
	{uL("SME"), uL("Sysmate Company")},
	{uL("SMI"), uL("SpaceLabs Medical Inc")},
	{uL("SMK"), uL("SMK CORPORATION")},
	{uL("SML"), uL("Sumitomo Metal Industries, Ltd.")},
	{uL("SMM"), uL("Shark Multimedia Inc")},
	{uL("SMO"), uL("STMicroelectronics")},
	{uL("SMP"), uL("Simple Computing")},
	{uL("SMR"), uL("B.& V. s.r.l.")},
	{uL("SMS"), uL("Silicom Multimedia Systems Inc")},
	{uL("SMT"), uL("Silcom Manufacturing Tech Inc")},
	{uL("SNC"), uL("Sentronic International Corp.")},
	{uL("SNI"), uL("Siemens Microdesign GmbH")},
	{uL("SNK"), uL("S&K Electronics")},
	{uL("SNN"), uL("SUNNY ELEKTRONIK")},
	{uL("SNO"), uL("SINOSUN TECHNOLOGY CO., LTD")},
	{uL("SNP"), uL("Siemens Nixdorf Info Systems")},
	{uL("SNS"), uL("Cirtech (UK) Ltd")},
	{uL("SNT"), uL("SuperNet Inc")},
	{uL("SNV"), uL("SONOVE GmbH")},
	{uL("SNW"), uL("Snell & Wilcox")},
	{uL("SNX"), uL("Sonix Comm. Ltd")},
	{uL("SNY"), uL("Sony")},
	{uL("SOC"), uL("Santec Corporation")},
	{uL("SOI"), uL("Silicon Optix Corporation")},
	{uL("SOL"), uL("Solitron Technologies Inc")},
	{uL("SON"), uL("Sony")},
	{uL("SOR"), uL("Sorcus Computer GmbH")},
	{uL("SOT"), uL("Sotec Company Ltd")},
	{uL("SOY"), uL("SOYO Group, Inc")},
	{uL("SPC"), uL("SpinCore Technologies, Inc")},
	{uL("SPE"), uL("SPEA Software AG")},
	{uL("SPH"), uL("G&W Instruments GmbH")},
	{uL("SPI"), uL("SPACE-I Co., Ltd.")},
	{uL("SPK"), uL("SpeakerCraft")},
	{uL("SPL"), uL("Smart Silicon Systems Pty Ltd")},
	{uL("SPN"), uL("Sapience Corporation")},
	{uL("SPO"), uL("SAMPO CORPORATION")},
	{uL("SPR"), uL("pmns GmbH")},
	{uL("SPS"), uL("Synopsys Inc")},
	{uL("SPT"), uL("Sceptre Tech Inc")},
	{uL("SPU"), uL("SIM2 Multimedia S.P.A.")},
	{uL("SPX"), uL("Simplex Time Recorder Co.")},
	{uL("SQT"), uL("Sequent Computer Systems Inc")},
	{uL("SRC"), uL("Integrated Tech Express Inc")},
	{uL("SRD"), uL("Setred")},
	{uL("SRF"), uL("Surf Communication Solutions Ltd")},
	{uL("SRG"), uL("Intuitive Surgical, Inc.")},
	{uL("SRS"), uL("SR-Systems e.K.")},
	{uL("SRT"), uL("SeeReal Technologies GmbH")},
	{uL("SSC"), uL("Sierra Semiconductor Inc")},
	{uL("SSD"), uL("FlightSafety International")},
	{uL("SSE"), uL("Samsung Electronic Co.")},
	{uL("SSI"), uL("S-S Technology Inc")},
	{uL("SSJ"), uL("Sankyo Seiki Mfg.co., Ltd")},
	{uL("SSL"), uL("Shenzhen South-Top Computer Co., Ltd.")},
	{uL("SSP"), uL("Spectrum Signal Proecessing Inc")},
	{uL("SSS"), uL("S3 Inc")},
	{uL("SST"), uL("SystemSoft Corporation")},
	{uL("STA"), uL("ST Electronics Systems Assembly Pte Ltd")},
	{uL("STB"), uL("STB Systems Inc")},
	{uL("STC"), uL("STAC Electronics")},
	{uL("STD"), uL("STD Computer Inc")},
	{uL("STE"), uL("SII Ido-Tsushin Inc")},
	{uL("STF"), uL("Starflight Electronics")},
	{uL("STG"), uL("StereoGraphics Corp.")},
	{uL("STH"), uL("Semtech Corporation")},
	{uL("STI"), uL("Smart Tech Inc")},
	{uL("STK"), uL("SANTAK CORP.")},
	{uL("STL"), uL("SigmaTel Inc")},
	{uL("STM"), uL("SGS Thomson Microelectronics")},
	{uL("STN"), uL("Samsung Electronics America")},
	{uL("STO"), uL("Stollmann E+V GmbH")},
	{uL("STP"), uL("StreamPlay Ltd")},
	{uL("STQ"), uL("Synthetel Corporation")},
	{uL("STR"), uL("Starlight Networks Inc")},
	{uL("STS"), uL("SITECSYSTEM CO., LTD.")},
	{uL("STT"), uL("Star Paging Telecom Tech (Shenzhen) Co. Ltd.")},
	{uL("STU"), uL("Sentelic Corporation")},
	{uL("STV"), uL("Beijing Guochengwantong Information Technology Co., Ltd.")},
	{uL("STW"), uL("Starwin Inc.")},
	{uL("STX"), uL("ST-Ericsson")},
	{uL("STY"), uL("SDS Technologies")},
	{uL("SUB"), uL("Subspace Comm. Inc")},
	{uL("SUM"), uL("Summagraphics Corporation")},
	{uL("SUN"), uL("Sun Electronics Corporation")},
	{uL("SUP"), uL("Supra Corporation")},
	{uL("SUR"), uL("Surenam Computer Corporation")},
	{uL("SVA"), uL("SGEG")},
	{uL("SVC"), uL("Intellix Corp.")},
	{uL("SVD"), uL("SVD Computer")},
	{uL("SVI"), uL("Sun Microsystems")},
	{uL("SVR"), uL("Sensics, Inc.")},
	{uL("SVS"), uL("SVSI")},
	{uL("SVT"), uL("SEVIT Co., Ltd.")},
	{uL("SWC"), uL("Software Café")},
	{uL("SWI"), uL("Sierra Wireless Inc.")},
	{uL("SWL"), uL("Sharedware Ltd")},
	{uL("SWO"), uL("Guangzhou Shirui Electronics Co., Ltd.")},
	{uL("SWS"), uL("Static")},
	{uL("SWT"), uL("Software Technologies Group,Inc.")},
	{uL("SXB"), uL("Syntax-Brillian")},
	{uL("SXD"), uL("Silex technology, Inc.")},
	{uL("SXG"), uL("SELEX GALILEO")},
	{uL("SXI"), uL("Silex Inside")},
	{uL("SXL"), uL("SolutionInside")},
	{uL("SXT"), uL("SHARP TAKAYA ELECTRONIC INDUSTRY CO.,LTD.")},
	{uL("SYC"), uL("Sysmic")},
	{uL("SYE"), uL("SY Electronics Ltd")},
	{uL("SYK"), uL("Stryker Communications")},
	{uL("SYL"), uL("Sylvania Computer Products")},
	{uL("SYM"), uL("Symicron Computer Communications Ltd.")},
	{uL("SYN"), uL("Synaptics Inc")},
	{uL("SYP"), uL("SYPRO Co Ltd")},
	{uL("SYS"), uL("Sysgration Ltd")},
	{uL("SYT"), uL("Seyeon Tech Company Ltd")},
	{uL("SYV"), uL("SYVAX Inc")},
	{uL("SYX"), uL("Prime Systems, Inc.")},
	{uL("SZM"), uL("Shenzhen MTC Co., Ltd")},
	{uL("TAA"), uL("Tandberg")},
	{uL("TAB"), uL("Todos Data System AB")},
	{uL("TAG"), uL("Teles AG")},
	{uL("TAI"), uL("Toshiba America Info Systems Inc")},
	{uL("TAM"), uL("Tamura Seisakusyo Ltd")},
	{uL("TAS"), uL("Taskit Rechnertechnik GmbH")},
	{uL("TAT"), uL("Teleliaison Inc")},
	{uL("TAV"), uL("Thales Avionics")},
	{uL("TAX"), uL("Taxan (Europe) Ltd")},
	{uL("TBB"), uL("Triple S Engineering Inc")},
	{uL("TBC"), uL("Turbo Communication, Inc")},
	{uL("TBS"), uL("Turtle Beach System")},
	{uL("TCC"), uL("Tandon Corporation")},
	{uL("TCD"), uL("Taicom Data Systems Co., Ltd.")},
	{uL("TCE"), uL("Century Corporation")},
	{uL("TCF"), uL("Televic Conference")},
	{uL("TCH"), uL("Interaction Systems, Inc")},
	{uL("TCI"), uL("Tulip Computers Int'l B.V.")},
	{uL("TCJ"), uL("TEAC America Inc")},
	{uL("TCL"), uL("Technical Concepts Ltd")},
	{uL("TCM"), uL("3Com Corporation")},
	{uL("TCN"), uL("Tecnetics (PTY) Ltd")},
	{uL("TCO"), uL("Thomas-Conrad Corporation")},
	{uL("TCR"), uL("Thomson Consumer Electronics")},
	{uL("TCS"), uL("Tatung Company of America Inc")},
	{uL("TCT"), uL("Telecom Technology Centre Co. Ltd.")},
	{uL("TCX"), uL("FREEMARS Heavy Industries")},
	{uL("TDC"), uL("Teradici")},
	{uL("TDD"), uL("Tandberg Data Display AS")},
	{uL("TDG"), uL("Six15 Technologies")},
	{uL("TDM"), uL("Tandem Computer Europe Inc")},
	{uL("TDP"), uL("3D Perception")},
	{uL("TDS"), uL("Tri-Data Systems Inc")},
	{uL("TDT"), uL("TDT")},
	{uL("TDV"), uL("TDVision Systems, Inc.")},
	{uL("TDY"), uL("Tandy Electronics")},
	{uL("TEA"), uL("TEAC System Corporation")},
	{uL("TEC"), uL("Tecmar Inc")},
	{uL("TEK"), uL("Tektronix Inc")},
	{uL("TEL"), uL("Promotion and Display Technology Ltd.")},
	{uL("TEN"), uL("Tencent")},
	{uL("TER"), uL("TerraTec Electronic GmbH")},
	{uL("TET"), uL("TETRADYNE CO., LTD.")},
	{uL("TEV"), uL("Televés, S.A.")},
	{uL("TEZ"), uL("Tech Source Inc.")},
	{uL("TGC"), uL("Toshiba Global Commerce Solutions, Inc.")},
	{uL("TGI"), uL("TriGem Computer Inc")},
	{uL("TGM"), uL("TriGem Computer,Inc.")},
	{uL("TGS"), uL("Torus Systems Ltd")},
	{uL("TGV"), uL("Grass Valley Germany GmbH")},
	{uL("TGW"), uL("TECHNOGYM S.p.A.")},
	{uL("THN"), uL("Thundercom Holdings Sdn. Bhd.")},
	{uL("TIC"), uL("Trigem KinfoComm")},
	{uL("TIL"), uL("Technical Illusions Inc.")},
	{uL("TIP"), uL("TIPTEL AG")},
	{uL("TIV"), uL("OOO Technoinvest")},
	{uL("TIX"), uL("Tixi.Com GmbH")},
	{uL("TKC"), uL("Taiko Electric Works.LTD")},
	{uL("TKG"), uL("Tek Gear")},
	{uL("TKN"), uL("Teknor Microsystem Inc")},
	{uL("TKO"), uL("TouchKo, Inc.")},
	{uL("TKS"), uL("TimeKeeping Systems, Inc.")},
	{uL("TLA"), uL("Ferrari Electronic GmbH")},
	{uL("TLD"), uL("Telindus")},
	{uL("TLE"), uL("Zhejiang Tianle Digital Electric Co., Ltd.")},
	{uL("TLF"), uL("Teleforce.,co,ltd")},
	{uL("TLI"), uL("TOSHIBA TELI CORPORATION")},
	{uL("TLK"), uL("Telelink AG")},
	{uL("TLL"), uL("Thinklogical")},
	{uL("TLN"), uL("Techlogix Networx")},
	{uL("TLS"), uL("Teleste Educational OY")},
	{uL("TLT"), uL("Dai Telecom S.p.A.")},
	{uL("TLV"), uL("S3 Inc")},
	{uL("TLX"), uL("Telxon Corporation")},
	{uL("TLY"), uL("Truly Semiconductors Ltd.")},
	{uL("TMC"), uL("Techmedia Computer Systems Corporation")},
	{uL("TME"), uL("AT&T Microelectronics")},
	{uL("TMI"), uL("Texas Microsystem")},
	{uL("TMM"), uL("Time Management, Inc.")},
	{uL("TMO"), uL("Terumo Corporation")},
	{uL("TMR"), uL("Taicom International Inc")},
	{uL("TMS"), uL("Trident Microsystems Ltd")},
	{uL("TMT"), uL("T-Metrics Inc.")},
	{uL("TMX"), uL("Thermotrex Corporation")},
	{uL("TNC"), uL("TNC Industrial Company Ltd")},
	{uL("TNJ"), uL("DO NOT USE - TNJ")},
	{uL("TNM"), uL("TECNIMAGEN SA")},
	{uL("TNY"), uL("Tennyson Tech Pty Ltd")},
	{uL("TOE"), uL("TOEI Electronics Co., Ltd.")},
	{uL("TOG"), uL("The OPEN Group")},
	{uL("TOL"), uL("TCL Corporation")},
	{uL("TOM"), uL("Ceton Corporation")},
	{uL("TON"), uL("TONNA")},
	{uL("TOP"), uL("Orion Communications Co., Ltd.")},
	{uL("TOS"), uL("Dynabook Inc.")},
	{uL("TOU"), uL("Touchstone Technology")},
	{uL("TPC"), uL("Touch Panel Systems Corporation")},
	{uL("TPD"), uL("Times (Shanghai) Computer Co., Ltd.")},
	{uL("TPE"), uL("Technology Power Enterprises Inc")},
	{uL("TPJ"), uL("Junnila")},
	{uL("TPK"), uL("TOPRE CORPORATION")},
	{uL("TPR"), uL("Topro Technology Inc")},
	{uL("TPS"), uL("Teleprocessing Systeme GmbH")},
	{uL("TPT"), uL("Thruput Ltd")},
	{uL("TPV"), uL("Top Victory Electronics ( Fujian ) Company Ltd")},
	{uL("TPZ"), uL("Ypoaz Systems Inc")},
	{uL("TRA"), uL("TriTech Microelectronics International")},
	{uL("TRB"), uL("Triumph Board a.s.")},
	{uL("TRC"), uL("Trioc AB")},
	{uL("TRD"), uL("Trident Microsystem Inc")},
	{uL("TRE"), uL("Tremetrics")},
	{uL("TRI"), uL("Tricord Systems")},
	{uL("TRL"), uL("Royal Information")},
	{uL("TRM"), uL("Tekram Technology Company Ltd")},
	{uL("TRN"), uL("Datacommunicatie Tron B.V.")},
	{uL("TRP"), uL("TRAPEZE GROUP")},
	{uL("TRS"), uL("Torus Systems Ltd")},
	{uL("TRT"), uL("Tritec Electronic AG")},
	{uL("TRU"), uL("Aashima Technology B.V.")},
	{uL("TRV"), uL("Trivisio Prototyping GmbH")},
	{uL("TRX"), uL("Trex Enterprises")},
	{uL("TSB"), uL("Toshiba America Info Systems Inc")},
	{uL("TSC"), uL("Sanyo Electric Company Ltd")},
	{uL("TSD"), uL("TechniSat Digital GmbH")},
	{uL("TSE"), uL("Tottori Sanyo Electric")},
	{uL("TSF"), uL("Racal-Airtech Software Forge Ltd")},
	{uL("TSG"), uL("The Software Group Ltd")},
	{uL("TSH"), uL("ELAN MICROELECTRONICS CORPORATION")},
	{uL("TSI"), uL("TeleVideo Systems")},
	{uL("TSL"), uL("Tottori SANYO Electric Co., Ltd.")},
	{uL("TSP"), uL("U.S. Navy")},
	{uL("TST"), uL("Transtream Inc")},
	{uL("TSV"), uL("TRANSVIDEO")},
	{uL("TSW"), uL("VRSHOW Technology Limited")},
	{uL("TSY"), uL("TouchSystems")},
	{uL("TTA"), uL("Topson Technology Co., Ltd.")},
	{uL("TTB"), uL("National Semiconductor Japan Ltd")},
	{uL("TTC"), uL("Telecommunications Techniques Corporation")},
	{uL("TTE"), uL("TTE, Inc.")},
	{uL("TTI"), uL("Trenton Terminals Inc")},
	{uL("TTK"), uL("Totoku Electric Company Ltd")},
	{uL("TTL"), uL("2-Tel B.V")},
	{uL("TTP"), uL("Toshiba Corporation")},
	{uL("TTR"), uL("Hubei Century Joint Innovation Technology Co.Ltd")},
	{uL("TTS"), uL("TechnoTrend Systemtechnik GmbH")},
	{uL("TTX"), uL("Taitex Corporation")},
	{uL("TTY"), uL("TRIDELITY Display Solutions GmbH")},
	{uL("TUA"), uL("T+A elektroakustik GmbH")},
	{uL("TUT"), uL("Tut Systems")},
	{uL("TVD"), uL("Tecnovision")},
	{uL("TVI"), uL("Truevision")},
	{uL("TVL"), uL("Total Vision LTD")},
	{uL("TVM"), uL("Taiwan Video & Monitor Corporation")},
	{uL("TVO"), uL("TV One Ltd")},
	{uL("TVR"), uL("TV Interactive Corporation")},
	{uL("TVS"), uL("TVS Electronics Limited")},
	{uL("TVV"), uL("TV1 GmbH")},
	{uL("TWA"), uL("Tidewater Association")},
	{uL("TWE"), uL("Kontron Electronik")},
	{uL("TWH"), uL("Twinhead International Corporation")},
	{uL("TWI"), uL("Easytel oy")},
	{uL("TWK"), uL("TOWITOKO electronics GmbH")},
	{uL("TWX"), uL("TEKWorx Limited")},
	{uL("TXL"), uL("Trixel Ltd")},
	{uL("TXN"), uL("Texas Insturments")},
	{uL("TXT"), uL("Textron Defense System")},
	{uL("TYN"), uL("Tyan Computer Corporation")},
	{uL("UAS"), uL("Ultima Associates Pte Ltd")},
	{uL("UBI"), uL("Ungermann-Bass Inc")},
	{uL("UBL"), uL("Ubinetics Ltd.")},
	{uL("UBU"), uL("Canonical Ltd.")},
	{uL("UDN"), uL("Uniden Corporation")},
	{uL("UEC"), uL("Ultima Electronics Corporation")},
	{uL("UEG"), uL("Elitegroup Computer Systems Company Ltd")},
	{uL("UEI"), uL("Universal Electronics Inc")},
	{uL("UET"), uL("Universal Empowering Technologies")},
	{uL("UFG"), uL("UNIGRAF-USA")},
	{uL("UFO"), uL("UFO Systems Inc")},
	{uL("UHB"), uL("XOCECO")},
	{uL("UIC"), uL("Uniform Industrial Corporation")},
	{uL("UJR"), uL("Ueda Japan Radio Co., Ltd.")},
	{uL("ULT"), uL("Ultra Network Tech")},
	{uL("UMC"), uL("United Microelectr Corporation")},
	{uL("UMG"), uL("Umezawa Giken Co.,Ltd")},
	{uL("UMM"), uL("Universal Multimedia")},
	{uL("UMT"), uL("UltiMachine")},
	{uL("UNA"), uL("Unisys DSD")},
	{uL("UNB"), uL("Unisys Corporation")},
	{uL("UNC"), uL("Unisys Corporation")},
	{uL("UND"), uL("DO NOT USE - UND")},
	{uL("UNE"), uL("DO NOT USE - UNE")},
	{uL("UNF"), uL("DO NOT USE - UNF")},
	{uL("UNI"), uL("Uniform Industry Corp.")},
	{uL("UNM"), uL("Unisys Corporation")},
	{uL("UNO"), uL("Unisys Corporation")},
	{uL("UNP"), uL("Unitop")},
	{uL("UNS"), uL("Unisys Corporation")},
	{uL("UNT"), uL("Unisys Corporation")},
	{uL("UNY"), uL("Unicate")},
	{uL("UPP"), uL("UPPI")},
	{uL("UPS"), uL("Systems Enhancement")},
	{uL("URD"), uL("Video Computer S.p.A.")},
	{uL("USA"), uL("Utimaco Safeware AG")},
	{uL("USD"), uL("U.S. Digital Corporation")},
	{uL("USE"), uL("U. S. Electronics Inc.")},
	{uL("USI"), uL("Universal Scientific Industrial Co., Ltd.")},
	{uL("USR"), uL("U.S. Robotics Inc")},
	{uL("UTC"), uL("Unicompute Technology Co., Ltd.")},
	{uL("UTD"), uL("Up to Date Tech")},
	{uL("UWC"), uL("Uniwill Computer Corp.")},
	{uL("VAD"), uL("Vaddio, LLC")},
	{uL("VAI"), uL("VAIO Corporation")},
	{uL("VAL"), uL("Valence Computing Corporation")},
	{uL("VAR"), uL("Varian Australia Pty Ltd")},
	{uL("VAT"), uL("VADATECH INC")},
	{uL("VAV"), uL("aviica")},
	{uL("VBR"), uL("VBrick Systems Inc.")},
	{uL("VBT"), uL("Valley Board Ltda")},
	{uL("VCC"), uL("Virtual Computer Corporation")},
	{uL("VCE"), uL("VARCem")},
	{uL("VCI"), uL("VistaCom Inc")},
	{uL("VCJ"), uL("Victor Company of Japan, Limited")},
	{uL("VCM"), uL("Vector Magnetics, LLC")},
	{uL("VCX"), uL("VCONEX")},
	{uL("VDA"), uL("Victor Data Systems")},
	{uL("VDC"), uL("VDC Display Systems")},
	{uL("VDM"), uL("Vadem")},
	{uL("VDO"), uL("Video & Display Oriented Corporation")},
	{uL("VDS"), uL("Vidisys GmbH & Company")},
	{uL("VDT"), uL("Viditec, Inc.")},
	{uL("VEC"), uL("Vector Informatik GmbH")},
	{uL("VEK"), uL("Vektrex")},
	{uL("VES"), uL("Vestel Elektronik Sanayi ve Ticaret A. S.")},
	{uL("VFI"), uL("VeriFone Inc")},
	{uL("VHI"), uL("Macrocad Development Inc.")},
	{uL("VIA"), uL("VIA Tech Inc")},
	{uL("VIB"), uL("Tatung UK Ltd")},
	{uL("VIC"), uL("Victron B.V.")},
	{uL("VID"), uL("Ingram Macrotron Germany")},
	{uL("VIK"), uL("Viking Connectors")},
	{uL("VIM"), uL("Via Mons Ltd.")},
	{uL("VIN"), uL("Vine Micros Ltd")},
	{uL("VIO"), uL("Zake IP Holdings LLC (3B tech)")},
	{uL("VIR"), uL("Visual Interface, Inc")},
	{uL("VIS"), uL("Visioneer")},
	{uL("VIT"), uL("Visitech AS")},
	{uL("VIZ"), uL("VIZIO, Inc")},
	{uL("VLB"), uL("ValleyBoard Ltda.")},
	{uL("VLC"), uL("VersaLogic Corporation")},
	{uL("VLK"), uL("Vislink International Ltd")},
	{uL("VLM"), uL("LENOVO BEIJING CO. LTD.")},
	{uL("VLT"), uL("VideoLan Technologies")},
	{uL("VLV"), uL("Valve Corporation")},
	{uL("VMI"), uL("Vermont Microsystems")},
	{uL("VML"), uL("Vine Micros Limited")},
	{uL("VMW"), uL("VMware Inc.,")},
	{uL("VNC"), uL("Vinca Corporation")},
	{uL("VOB"), uL("MaxData Computer AG")},
	{uL("VPI"), uL("Video Products Inc")},
	{uL("VPR"), uL("Best Buy")},
	{uL("VPX"), uL("VPixx Technologies Inc.")},
	{uL("VQ@"), uL("Vision Quest")},
	{uL("VRC"), uL("Virtual Resources Corporation")},
	{uL("VRG"), uL("VRgineers, Inc.")},
	{uL("VRM"), uL("VRmagic Holding AG")},
	{uL("VRS"), uL("VRstudios, Inc.")},
	{uL("VRT"), uL("Varjo Technologies")},
	{uL("VSC"), uL("ViewSonic Corporation")},
	{uL("VSD"), uL("3M")},
	{uL("VSI"), uL("VideoServer")},
	{uL("VSN"), uL("Ingram Macrotron")},
	{uL("VSP"), uL("Vision Systems GmbH")},
	{uL("VSR"), uL("V-Star Electronics Inc.")},
	{uL("VTB"), uL("Videotechnik Breithaupt")},
	{uL("VTC"), uL("VTel Corporation")},
	{uL("VTG"), uL("Voice Technologies Group Inc")},
	{uL("VTI"), uL("VLSI Tech Inc")},
	{uL("VTK"), uL("Viewteck Co., Ltd.")},
	{uL("VTL"), uL("Vivid Technology Pte Ltd")},
	{uL("VTM"), uL("Miltope Corporation")},
	{uL("VTN"), uL("VIDEOTRON CORP.")},
	{uL("VTS"), uL("VTech Computers Ltd")},
	{uL("VTV"), uL("VATIV Technologies")},
	{uL("VTX"), uL("Vestax Corporation")},
	{uL("VUT"), uL("Vutrix (UK) Ltd")},
	{uL("VWB"), uL("Vweb Corp.")},
	{uL("WAC"), uL("Wacom Tech")},
	{uL("WAL"), uL("Wave Access")},
	{uL("WAN"), uL("DO NOT USE - WAN")},
	{uL("WAV"), uL("Wavephore")},
	{uL("WBN"), uL("MicroSoftWare")},
	{uL("WBS"), uL("WB Systemtechnik GmbH")},
	{uL("WCI"), uL("Wisecom Inc")},
	{uL("WCS"), uL("Woodwind Communications Systems Inc")},
	{uL("WDC"), uL("Western Digital")},
	{uL("WDE"), uL("Westinghouse Digital Electronics")},
	{uL("WEB"), uL("WebGear Inc")},
	{uL("WEC"), uL("Winbond Electronics Corporation")},
	{uL("WEL"), uL("W-DEV")},
	{uL("WEY"), uL("WEY Design AG")},
	{uL("WHI"), uL("Whistle Communications")},
	{uL("WII"), uL("Innoware Inc")},
	{uL("WIL"), uL("WIPRO Information Technology Ltd")},
	{uL("WIN"), uL("Wintop Technology Inc")},
	{uL("WIP"), uL("Wipro Infotech")},
	{uL("WKH"), uL("Uni-Take Int'l Inc.")},
	{uL("WLD"), uL("Wildfire Communications Inc")},
	{uL("WLF"), uL("WOLF Advanced Technology")},
	{uL("WML"), uL("Wolfson Microelectronics Ltd")},
	{uL("WMO"), uL("Westermo Teleindustri AB")},
	{uL("WMT"), uL("Winmate Communication Inc")},
	{uL("WNI"), uL("WillNet Inc.")},
	{uL("WNV"), uL("Winnov L.P.")},
	{uL("WNX"), uL("Diebold Nixdorf Systems GmbH")},
	{uL("WPA"), uL("Matsushita Communication Industrial Co., Ltd.")},
	{uL("WPI"), uL("Wearnes Peripherals International (Pte) Ltd")},
	{uL("WRC"), uL("WiNRADiO Communications")},
	{uL("WSC"), uL("CIS Technology Inc")},
	{uL("WSP"), uL("Wireless And Smart Products Inc.")},
	{uL("WST"), uL("Wistron Corporation")},
	{uL("WTC"), uL("ACC Microelectronics")},
	{uL("WTI"), uL("WorkStation Tech")},
	{uL("WTK"), uL("Wearnes Thakral Pte")},
	{uL("WTS"), uL("Restek Electric Company Ltd")},
	{uL("WVM"), uL("Wave Systems Corporation")},
	{uL("WVV"), uL("WolfVision GmbH")},
	{uL("WWP"), uL("Wipotec Wiege- und Positioniersysteme GmbH")},
	{uL("WWV"), uL("World Wide Video, Inc.")},
	{uL("WXT"), uL("Woxter Technology Co. Ltd")},
	{uL("WYR"), uL("WyreStorm Technologies LLC")},
	{uL("WYS"), uL("Myse Technology")},
	{uL("WYT"), uL("Wooyoung Image & Information Co.,Ltd.")},
	{uL("XAC"), uL("XAC Automation Corp")},
	{uL("XAD"), uL("Alpha Data")},
	{uL("XDM"), uL("XDM Ltd.")},
	{uL("XER"), uL("DO NOT USE - XER")},
	{uL("XES"), uL("Extreme Engineering Solutions, Inc.")},
	{uL("XFG"), uL("Jan Strapko - FOTO")},
	{uL("XFO"), uL("EXFO Electro Optical Engineering")},
	{uL("XIN"), uL("Xinex Networks Inc")},
	{uL("XIO"), uL("Xiotech Corporation")},
	{uL("XIR"), uL("Xirocm Inc")},
	{uL("XIT"), uL("Xitel Pty ltd")},
	{uL("XLX"), uL("Xilinx, Inc.")},
	{uL("XMM"), uL("C3PO S.L.")},
	{uL("XNT"), uL("XN Technologies, Inc.")},
	{uL("XOC"), uL("DO NOT USE - XOC")},
	{uL("XQU"), uL("SHANGHAI SVA-DAV ELECTRONICS CO., LTD")},
	{uL("XRC"), uL("Xircom Inc")},
	{uL("XRO"), uL("XORO ELECTRONICS (CHENGDU) LIMITED")},
	{uL("XSN"), uL("Xscreen AS")},
	{uL("XST"), uL("XS Technologies Inc")},
	{uL("XSY"), uL("XSYS")},
	{uL("XTD"), uL("Icuiti Corporation")},
	{uL("XTE"), uL("X2E GmbH")},
	{uL("XTL"), uL("Crystal Computer")},
	{uL("XTN"), uL("X-10 (USA) Inc")},
	{uL("XYC"), uL("Xycotec Computer GmbH")},
	{uL("XYE"), uL("Shenzhen Zhuona Technology Co., Ltd.")},
	{uL("YED"), uL("Y-E Data Inc")},
	{uL("YHQ"), uL("Yokogawa Electric Corporation")},
	{uL("YHW"), uL("Exacom SA")},
	{uL("YMH"), uL("Yamaha Corporation")},
	{uL("YOW"), uL("American Biometric Company")},
	{uL("ZAN"), uL("Zandar Technologies plc")},
	{uL("ZAX"), uL("Zefiro Acoustics")},
	{uL("ZAZ"), uL("ZeeVee, Inc.")},
	{uL("ZBR"), uL("Zebra Technologies International, LLC")},
	{uL("ZBX"), uL("Zebax Technologies")},
	{uL("ZCT"), uL("ZeitControl cardsystems GmbH")},
	{uL("ZDS"), uL("Zenith Data Systems")},
	{uL("ZEN"), uL("ZENIC Inc.")},
	{uL("ZGT"), uL("Zenith Data Systems")},
	{uL("ZIC"), uL("Nationz Technologies Inc.")},
	{uL("ZMC"), uL("HangZhou ZMCHIVIN")},
	{uL("ZMT"), uL("Zalman Tech Co., Ltd.")},
	{uL("ZMZ"), uL("Z Microsystems")},
	{uL("ZNI"), uL("Zetinet Inc")},
	{uL("ZNX"), uL("Znyx Adv. Systems")},
	{uL("ZOW"), uL("Zowie Intertainment, Inc")},
	{uL("ZRN"), uL("Zoran Corporation")},
	{uL("ZSE"), uL("Zenith Data Systems")},
	{uL("ZTC"), uL("ZyDAS Technology Corporation")},
	{uL("ZTE"), uL("ZTE Corporation")},
	{uL("ZTI"), uL("Zoom Telephonics Inc")},
	{uL("ZTM"), uL("ZT Group Int'l Inc.")},
	{uL("ZTT"), uL("Z3 Technology")},
	{uL("ZWE"), uL("Shenzhen Zowee Technology Co., LTD")},
	{uL("ZYD"), uL("Zydacron Inc")},
	{uL("ZYP"), uL("Zypcom Inc")},
	{uL("ZYT"), uL("Zytex Computers")},
	{uL("ZYX"), uL("Zyxel")},
	{uL("ZZZ"), uL("Boca Research Inc")},
};
